%define current_version 3.0.0.38

%define rcver %{nil}

Name: criu
Version: %{current_version}
Release:        1%{?dist}
Provides: crtools = %{version}-%{release}
Obsoletes: crtools <= 1.0-2
Summary: Tool for Checkpoint/Restore in User-space
Group: System Environment/Base
License: GPLv2
URL: http://criu.org/
Source: %{name}-%{version}.tar.bz2

BuildRequires: protobuf-devel protobuf-c-devel libnl3-devel libcap-devel asciidoc xmlto python2-devel libnet-devel

Requires: spfs

# user-space and kernel changes are only available for x86_64 and ARM
# code is very architecture specific
# once imported in RCS it needs a bug openend explaining the ExclusiveArch
# https://bugzilla.redhat.com/show_bug.cgi?id=902875
ExclusiveArch: x86_64 %{arm}

%description
criu is the user-space part of Checkpoint/Restore in User-space
(CRIU), a project to implement checkpoint/restore functionality for
Linux in user-space.

%package devel
Summary: Header files and libraries for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
This package contains header files and libraries for %{name}.

%package -n python-%{name}
Summary: Python bindings for %{name}
Group: Development/Languages
Requires: %{name} = %{version}-%{release}
Requires: protobuf-python
Requires: python-ipaddr

%description -n python-%{name}
python-%{name} contains Python bindings for %{name}.

%package -n crit
Summary: CRIU image tool
Requires: python-%{name} = %{version}-%{release}

%description -n crit
crit is a tool designed to decode CRIU binary dump files and show
their content in human-readable form.

%package -n libcompel
Summary: A library to execute arbitrary code in a context of a foreign process
Group: System Environment/Base
Conflicts: %{name} < 3.0.0.11-2

%description -n libcompel
A library to execute arbitrary code in a context of a foreign process.

%package -n libcompel-devel
Summary: Header files and libraries for libcompel
Group: Development/Libraries
Requires: libcompel = %{version}-%{release}
Conflicts: %{name} < 3.0.0.11-2
Conflicts: %{name}-devel < 3.0.0.11-2

%description -n libcompel-devel
The libcompel-devel package contains libraries, scripts and header files for
developing applications that use libcompel.

%prep
%setup -q

%build
# %{?_smp_mflags} does not work
# -fstack-protector breaks build
CFLAGS+=`echo %{optflags} | sed -e 's,-fstack-protector\S*,,g'` make V=1 WERROR=0 PREFIX=%{_prefix}
make docs V=1


%install
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d
make install DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LIBDIR=%{_libdir} LIBEXECDIR=%{_libexecdir} LOGROTATEDIR=%{_sysconfdir}/logrotate.d

# upstream renamed to binary to criu
ln -s %{_sbindir}/criu $RPM_BUILD_ROOT%{_sbindir}/crtools

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post -n libcompel -p /sbin/ldconfig
%postun -n libcompel -p /sbin/ldconfig

%files
%{_sbindir}/%{name}
%{_sbindir}/crtools
%{_libdir}/libcriu.so.*
%{_libexecdir}/criu
%doc %{_mandir}/man8/criu.8*
%doc %{_mandir}/man1/crit.1*
%doc README.md COPYING

%files devel
%{_includedir}/criu
%{_libdir}/libcriu.so
%{_libdir}/pkgconfig/criu.pc

%files -n python-%{name}
%{python2_sitelib}/pycriu/*
%{python2_sitelib}/*egg-info

%files -n crit
%{_bindir}/crit

%files -n libcompel
%{_bindir}/compel
%{_libdir}/libcompel.so.*

%files -n libcompel-devel
%{_libdir}/libcompel.a
%{_libdir}/libcompel.so
%{_includedir}/compel
%{_libexecdir}/compel


%changelog
* Mon Aug 14 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.38
 - test: mount -- Add bind-mount-unix
 - sk-unix: Handle bindmounted dgram sockets on restore (#PSBM-69473)
 - sk-unix: Save mnt_id for bindmounted entries (#PSBM-69473)

* Tue Aug 08 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.37
 - version: Force increase for hf1
 - fsnotify: open_handle -- Handle multiple mounts with same s_dev (#PSBM-69473)
 - Log into /var/log/mesages large ghost files dumps (#PSBM-68320)

* Tue Aug 08 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.35
 - fsnotify: open_handle -- Handle multiple mounts with same s_dev (#PSBM-69473)
 - Log into /var/log/mesages large ghost files dumps (#PSBM-68320)

* Fri Jul 28 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.34
 - pie, restorer: Fix typo in wait_helpers (#PSBM-69378)

* Thu Jul 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.33
 - page-xfer: Make error message more verbose (#PSBM-68738)

* Thu Jul 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.32
 - Revert "sfd: Reserve service descriptors early" (#PSBM-69279 #PSBM-69259)
 - Revert "sfd: Don't forget to close pre-opened tty service fd"

* Wed Jul 26 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.31
 - sfd: Don't forget to close pre-opened tty service fd (#PSBM-69211)

* Wed Jul 26 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.30
 - sfd: Reserve service descriptors early (#PSBM-68738)

* Mon Jul 24 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.29
 - vz7/cgroup: Skip for awhile ifpriomap property restore (#PSBM-66683)

* Mon Jul 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.28
 - vz7: bc, restore -- Check for failcounters on error (#PSBM-68868)
 - vz7: criu: update second "iptables restore" helper to work in VE#0 (#PSBM-58574)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint

* Mon Jul 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.27
 - vz7: criu: update second "iptables restore" helper to work in VE#0 (#PSBM-58574)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint

* Mon Jul 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.26
 - vz7: criu: threads -- Allow uids/gids being different (#PSBM-68756)
 - vz7: sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (#PSBM-68062)
 - vz7: mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (#PSBM-68062)

* Fri Jul 21 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.25
 - net: do iptables restore in ve0 (#PSBM-58574)
 - net: iptables_tool_{dump,restore} helpers introduced
 - criu: export join_ve helper

* Thu Jul 20 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.24
 - restore: Fix deadlock when helper's child dies (#PSBM-67930)
 - page-xfer: handle a case when splice returns zero (#PSBM-68732)

* Wed Jul 19 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.23
 - mount: allow any types of NFS mount for a while (#PSBM-68663)

* Wed Jul 19 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.22
 - mounts: support NFS bind-mounts in the same shared group (#PSBM-68663)

* Tue Jul 18 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.21
 - criu: don't abort criu in lookup_create_item() (#PSBM-68607)
 - dump: set pid->state for threads (#PSBM-68585)
 - mounts: support only shared NFS mounts in inits mount namespace (#PSBM-66945)

* Sat Jul 15 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.20
 - mount: Switch user_ns before mount binfmt_misc (#PSBM-68377)
 - ve: Call binfmt_misc-mounting code in call_in_child_process()
 - util: Implement clone_in_child_process() helper
 - clone_noasan: Allow to create CLONE_VM|CLONE_VFORK processes
 - mount: Move binfmt_misc-mounting code to separate function
 - mount: Consider EBUSY binfmt_misc mount return as error

* Wed Jul 12 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.19
 - vz7: files -- Don't access value from stack in outer contex
 - mount: Don't search for siblings inside self (#PSBM-67723)
 - vz7: vdso: Map vdso with arch_prctl() if kdat.can_map_vdso (#PSBM-67017)
 - vdso/restorer: Don't map compatible vdso if it was unmapped
 - vdso: Don't park vdso/vvar if restoree doesn't have them
 - kdat: Add test for presence of vdso mapping API
 - vz7: vdso: Don't read pagemap or parse symtable (#PSBM-67017)
 - vdso: Introduce type for checking vdso hint in maps file
 - vz7: sk-queue: fix non-fatal print log level
 - vz7: netlink: fix warning print

* Wed Jul 12 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.18
 - vz7: vdso: Map vdso with arch_prctl() if kdat.can_map_vdso (#PSBM-67017)
 - vdso/restorer: Don't map compatible vdso if it was unmapped
 - vdso: Don't park vdso/vvar if restoree doesn't have them
 - kdat: Add test for presence of vdso mapping API
 - vz7: vdso: Don't read pagemap or parse symtable (#PSBM-67017)
 - vdso: Introduce type for checking vdso hint in maps file
 - vz7: sk-queue: fix non-fatal print log level
 - vz7: netlink: fix warning print

* Fri Jun 30 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.17
 - cr-service: Init page_ids laterly
 - images: Initialize images earlier (before page-server starts) (#PSBM-67335)
 - pages: Share page_ids between ns dump-helpers (#PSBM-67335)
 - vz7: mount: check for mount is unsupported only on dump
 - vz7: files-reg: forbid migration of opened device files on NFS (#PSBM-55590)

* Thu Jun 29 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.16
 - images: Initialize images earlier (before page-server starts) (#PSBM-67335)
 - pages: Share page_ids between ns dump-helpers (#PSBM-67335)
 - vz7: mount: check for mount is unsupported only on dump
 - vz7: files-reg: forbid migration of opened device files on NFS (#PSBM-55590)

* Thu Jun 29 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.15
 - pages: Share page_ids between ns dump-helpers (#PSBM-67335)
 - vz7: mount: check for mount is unsupported only on dump
 - vz7: files-reg: forbid migration of opened device files on NFS (#PSBM-55590)

* Fri Jun 23 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.14
 - scripts: cleanup error output in systemd-autofs-restart.sh (#PSBM-67544)
 - scripts: check service mountpoint is not empty in systemd-autofs-restart.sh (#PSBM-67544)

* Wed Jun 21 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.13
 - mem: Don't assume guard page is returned in procfs with new kernels (#PSBM-67433)
 - kerndat: Detect if we have guard page mangle in procfs output

* Tue Jun 20 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.12
 - mounts: print NFS nested mountpoint info (#PSBM-67466)
 - mounts: add unsupported mount helper (#PSBM-67466)

* Mon Jun 19 2017 Andrey Bondrov <abondrov@virtuozzo.com> 3.0.0.11-3
- Drop libcompel explicit dependency from criu

* Mon Jun 19 2017 Andrey Bondrov <abondrov@virtuozzo.com> 3.0.0.11-2
- Split libcompel and libcompel-devel to subpackages

* Fri Jun 09 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.11
 - spfs: fix usage of mi->ns_mountpoint (#PSBM-66943)
 - spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager (#PSBM-66943)

* Thu Jun 08 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.10
 - Revert "vz7: sfd: Move service fd helpers into separate file" (#PSBM-65382)
 - Revert "vz7: sfd: Rework install, clone helpers to use fcntl" (#PSBM-65382)
 - Revert "vz7: sfd -- Don't forget to skip reserved fds on clone" (#PSBM-65382)
 - files: remove extra newline from a message

* Tue Jun 06 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.9
 - mount: don't use phys_stat_resolve_dev() in open_mount() (#PSBM-66981)
 - vz7: tests: shm-unaligned -- Use unique key for simultaneous run (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-66764)

* Fri Jun 02 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.8
 - scripts: use absolute binaries paths systemd-autofs-restart.sh (#PSBM-66967)

* Thu Jun 01 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.7
 - zdtm: run page-server via rpc
 - lib/py: allow to execute page-server as a child process
 - service: allow to execute page-server as a child process
 - scripts: use absolute binaries paths nfs-ports-allow.sh (#PSBM-66901)

* Thu Jun 01 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.6
 - ia32/feature-test: Don't check i686 libraries presence
 - nmk: Provide try-asm build check function
 - mount: Find NS_ROOT for cr-time mount on restore (#PSBM-66457)

* Thu Jun 01 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.5
 - vz7: sfd -- Don't forget to skip reserved fds on clone (#PSBM-66874)

* Wed May 31 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.4
 - Revert "vz7: Unlimit self RLIMIT_NOFILE resource for dump/predump"
 - Revert "vz7: restore -- Lift up own file limits"
 - vz7: sfd: Lift up own fd limit on bootup (#PSBM-65382)
 - vz7: kdat: Add fetching files stat (#PSBM-65382)
 - vz7: sfd: Rework install, clone helpers to use fcntl (#PSBM-65382)
 - vz7: sfd: Move service fd helpers into separate file (#PSBM-65382)
 - x86/ia32: fix build with DEBUG=1 (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - vdso/compat: Don't unmap missing vdso/vvar vmas (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - pie/vdso: return back ELF header mismatch error (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - ia32/futex: restore compat_robust_list (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - ia32/futex: add dumping compat_robust_list (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - restorer: remove always true `has_futex' arg (Dmitry Safonov <dsafonov@virtuozzo.com>)

* Fri May 12 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.3
 - scripts: skip spfs mount points in systemd-autofs-restart.sh (#PSBM-66285)
 - scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh
 - scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
 - vz7: tests -- Drop _GNU_SOURCE from source code (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-66278)

* Thu May 11 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.2
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - make: Report dependencies absence more exactly
 - ia32: Rename has_compat_sigreturn => compat_cr
 - ia32: Clearify if 32bit C/R is compile-disabled

* Thu May 11 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.1
 - vz7: Makefile.version -- Adjust number for new series
 - vz7: Makefile: Fix scripts installation
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join (#PSBM-65483)
 - vz7: tty: Make sure no /dev/tty inheritance exist (#PSBM-65637)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (#PSBM-65185)
 - vz7: test: sk-unix01 -- Make sure the dir with ghost files are empty
 - vz7: sk-unix: Don't wait on socketpair (#PSBM-65051)
 - vz7: sk-unix -- Add info print about slave peers
 - vz7: sk-unix -- Adjust default dgram qlen for systemd sake (#PSBM-64628)
 - vz7: sk-unix -- Fix typo in namelen comparision (#PSBM-64715)
 - vz7: sk-queue: Add missing newline into log
 - vz7: restore_sk_queue -- Show how many bytes already sent (#PSBM-64628)
 - vz7: test: sk-unix01 -- Fix compilation
 - vz7: sk-unix: Don't append ghost postfix on subsequent checkpoint (#PSBM-55992)
 - test: Add sk-unix01 test
 - vz7: sk-unix: Add ability to restore sockets with deleted vfs addresses
 - vz7: sk-unix: Print cwd been restored if @name_dir is present
 - vz7: sk-unix: Don't warn if nothing to unlink
 - vz7: sk-unix: Collect deleted identical addresses in the queues
 - vz7: sk-unix: Make USK_ flags in shift form
 - vz7: sk-unix: Drop empty line at eof
 - vz7: sk-unix: Use add_post_prepare_cb_once helper
 - vz7: sk-unix: Drop empty line
 - vz7: sk-unix: Use generic xptr_pull in dump_one_unix_fd
 - vz7: sk-unix: Use native types in unix_sk_info
 - vz7: sk-unix: Adjust unix_sk_info members
 - vz7: sk-unix: Adjust unix_sk_cinfo members
 - vz7: sk-unix: Make can_dump_unix_sk being boolean
 - vz7: pipes: Use add_post_prepare_cb_once
 - vz7: tty: Use add_post_prepare_cb_once
 - vz7: restore: Add add_post_prepare_cb_once helper
 - sk-queue: Don't fail if we're dumping dead process queued creds (#PSBM-62778)
 - vz7: sk-queue -- Show the creds we're sending (#PSBM-64009)
 - vz7: sk-queue -- Show peers in hex form (#PSBM-64009)
 - vz7: seize -- Wait for seize in thawed state (#PSBM-63841)
 - vz7: freezer -- Add set_freezer_state helper (#PSBM-63841)
 - vz7: epoll -- Dont fail on dup'ed fd restore (#PSBM-63850)
 - vz7: dump: Any non-negative return code of run_scripts means an error (#PSBM-62583)
 - vz7: sk-unix -- Restore qlen before pushing queued data back (#PSBM-63762)
 - vz7: sockets: Separate socket buffer size setting into a helper (#PSBM-63762)
 - vz7: seize -- Show detached pid in freezer_detach
 - vz7: Show status of uninterruptable task (#PSBM-63211)
 - vz7: files -- Select proper master fd when collecting fd (#PSBM-63355)
 - vz7: pstree -- Introduce pstree_pid_cmp helper
 - vz7: page-xfer -- Handle partial splicing (#PSBM-63161)
 - vz7: ucred -- Drop packets from dead processes (#PSBM-62603)
 - vz7: epoll -- Use real file transferred for target fds check (#PSBM-62108)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (#PSBM-61095)
 - test: Add ucreds test
 - vz7: pagemap -- Use ssize_t type where appropriate (#PSBM-62199)
 - vz7: compel -- Use unsigned long for arguments (#PSBM-61961)
 - vz7: dump -- Set file limits back before fetching them into dump (#PSBM-61812)
 - vz7: Drop redundant comment
 - vz7: restore -- Lift up own file limits (#PSBM-63094)
 - vz7: Unlimit self RLIMIT_NOFILE resource for dump/predump (#PSBM-63002)
 - vz7: Unlimit and limit file number resource for c/r sake (#PSBM-61573)
 - vz7: kdat: Add fetching files stat
 - vz7: Don't forget to restore memory cgroup limits on pre-dupms (#PSBM-61534 #PSBM-53593)
 - vz7: Zap file size checking for "atop" (#PSBM-61459)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (#PSBM-61248)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (#PSBM-60643)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32
 - vz7: socket: don't restore ucred from kernel messages
 - vz7: netlink: dump/restore netlink options
 - vz7: netlink: restore queues and only then restore opts
 - vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly (#PSBM-60606 #PSBM-61459 #PSBM-61851)
 - vz7: mount -- Add lookup_first_fstype helper
 - vz7: criu: add more information about control messages (#PSBM-60643)
 - vz7: test: check ucred for netlink messages
 - vz7: netlink: dump and restore ucred-s for netlink messages (#PSBM-59339)
 - vz7: eventpoll: Skip inaccessible descriptors (#PSBM-60042)
 - vz7: pipes -- Restore pipe size via userns call (#PSBM-59829)
 - vz7: mount: fix mounting non-root shared mounts (#PSBM-55494)
 - vz7: test: pty05 -- Add testing of multiple devpts instance
 - vz7: tty -- Don't fail if @mnt_id is not present in images (#PSBM-60606)
 - vz7: tty: Fix devpts mounts resolving (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (#PSBM-58616)
 - vz7: tty: Save mount ids for terminals into image
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper
 - vz7: tty: Save task current terminal if present
 - vz7: Unlimit UBC when chekpointing (#PSBM-53593)
 - vz7: restore -- Enter destination veX once usernsd is up (#PSBM-56407)
 - vz7: Make get_dumpee_veid been exported
 - vz7: zdtm: check a netlink socket with in-kernel state
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
 - vz7: sk-inet: Fix lookup for raw sockets (#PSBM-55835)
 - vz7: shmem: skip zero pages
 - vz7: shmem: don't write zero pages into an image
 - vz7: seccomp -- Switch to prctl interface if syscall is not implemented (#PSBM-55593)
 - vz7: ghost files: don't check ghost size if it's an NFS path (#PSBM-56159)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED
 - vz7: test: Add simple socket-raw test
 - vz7: sk-inet: Add initial support for raw sockets (#PSBM-51614)
 - vz7: Don't use executable stacks in @syscall_ip (#PSBM-55989)
 - vz7: util: Add rmdirp helper
 - vz7: mount: handle error from restore_shared_options()
 - vz7: seize: Add additional diagnose messages (#PSBM-53929)
 - vz7: mount: bind-mount autofs mounts via a file descriptors (#PSBM-53194)
 - vz7: spfs: create control socket in /run/spfs-manager/<pid> (#PSBM-59199)
 - vz7: spfs: move SPFS manager to corresponding container's dump directory
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (#PSBM-52353)
 - vz7: mnt -- Fetch VEID from cgroup for migration sake (#PSBM-52372)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (#PSBM-52320)
 - vz7: cg: Don't dump devices.list (#PSBM-50551)
 - vz7: scripts: remove obsolete scripts
 - vz7: cr-restore: use spfs helpers to control spfs manager
 - vz7: spfs: add new helpers to replces bash scripts calls
 - vz7: files-reg: move ghost_apply_metadata out of create_ghost_dentry
 - vz7: mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - vz7: files-reg: fix silly-renamed files migration
 - vz7: files-reg: improve spfs_file helper
 - vz7: Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - vz7: files: Allow to dump ploopX files opened (#PSBM-49723)
 - vz7: spfs: remove obsolete code
 - vz7: files-reg: migrate "spfs" files as ghost-ones
 - vz7: files-reg: conditionally dump content in dump_ghost_file
 - vz7: util: mkdirname helper introduced
 - vz7: files-reg: split create_ghost
 - vz7: files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - vz7: dump: Show task comm early
 - vz7: spfs: do not tolerate file existence on creation
 - vz7: spfs: fix freeze cgroup path discovery
 - vz7: cgroup: new_cg_root_get helper introduced
 - vz7: criu: remove NFS unlinked files restriction
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects
 - vz7: files-reg: migrate spfs file as "link remap" objects
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - vz7: spfs: explicitly pass size and mode to spfs_create_file
 - vz7: link_remap: do not create excessive links for a single file
 - vz7: mount: forbid dumping overmounted NFS (#PSBM-48620)
 - vz7: zdtm: add a new test to check netlink sockets with queued data
 - vz7: netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages
 - vz7: check: check whether NETLINK_REPAIR is supported or not
 - vz7: netlink: request flags for netlink sockets
 - vz7: files-reg: forbid to dump unlinked NFS files
 - vz7: proc_parse: forbid dumping NFS remote locks
 - vz7: files-reg: remove "unreachable" protobuf field as redundant
 - vz7: files-reg: create spfs file in case of parent mount is SPFS
 - vz7: files-reg: do not create spfs file in case of external resource
 - vz7: spfs: remove "ns_list" option from "replace" command as obsolete
 - vz7: compel -- Add support for vz7 specific cpuid masking (#PSBM-47748 #PSBM-49423)
 - vz7: scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - vz7: scripts: restart all systemd automount services (#PSBM-46672)
 - vz7: sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - vz7: util: Add cr_set_root/cr_restore_root helpers
 - vz7: spfs: do not treat existent file as error in create_reg_file
 - vz7: scripts: spfs-release-replace.sh introduced
 - vz7: criu: spfs -- Fixup various nits for NFS sake
 - vz7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - vz7: mount: Add support for NFSv4
 - vz7: protobuf/mnt.proto: NFSv4 type added
 - vz7: mount: add support for NFS
 - vz7: protobuf/mnt.proto: NFS type added
 - vz7: mount: add support for SUNRPC Pipefs
 - vz7: protobuf/mnt.proto: RPC Pipefs type added
 - vz7: scripts: allow-nfs-ports.sh added
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added
 - vz7: scripts: spfs-change-mode.sh added
 - vz7: action scripts: set spfs environment in run_scripts
 - vz7: regular files: create temporary spfs file if marked as unreachable
 - vz7: spfs: delayed mounts facility introduced
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd
 - vz7: regular files: protobuf "unreachable" field introduced
 - vz7: filemap: collect mapped file fs type
 - vz7: reg_file_entry: add "mode" variable
 - vz7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - vz7: Wait aio pending requests (#PSBM-42488)
 - vz7: criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - vz7: Merge vanilla 3.0

* Thu May 11 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.1
 - vz7: Makefile.version -- Adjust number for new series
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join (#PSBM-65483)
 - vz7: tty: Make sure no /dev/tty inheritance exist (#PSBM-65637)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (#PSBM-65185)
 - vz7: test: sk-unix01 -- Make sure the dir with ghost files are empty
 - vz7: sk-unix: Don't wait on socketpair (#PSBM-65051)
 - vz7: sk-unix -- Add info print about slave peers
 - vz7: sk-unix -- Adjust default dgram qlen for systemd sake (#PSBM-64628)
 - vz7: sk-unix -- Fix typo in namelen comparision (#PSBM-64715)
 - vz7: sk-queue: Add missing newline into log
 - vz7: restore_sk_queue -- Show how many bytes already sent (#PSBM-64628)
 - vz7: test: sk-unix01 -- Fix compilation
 - vz7: sk-unix: Don't append ghost postfix on subsequent checkpoint (#PSBM-55992)
 - test: Add sk-unix01 test
 - vz7: sk-unix: Add ability to restore sockets with deleted vfs addresses
 - vz7: sk-unix: Print cwd been restored if @name_dir is present
 - vz7: sk-unix: Don't warn if nothing to unlink
 - vz7: sk-unix: Collect deleted identical addresses in the queues
 - vz7: sk-unix: Make USK_ flags in shift form
 - vz7: sk-unix: Drop empty line at eof
 - vz7: sk-unix: Use add_post_prepare_cb_once helper
 - vz7: sk-unix: Drop empty line
 - vz7: sk-unix: Use generic xptr_pull in dump_one_unix_fd
 - vz7: sk-unix: Use native types in unix_sk_info
 - vz7: sk-unix: Adjust unix_sk_info members
 - vz7: sk-unix: Adjust unix_sk_cinfo members
 - vz7: sk-unix: Make can_dump_unix_sk being boolean
 - vz7: pipes: Use add_post_prepare_cb_once
 - vz7: tty: Use add_post_prepare_cb_once
 - vz7: restore: Add add_post_prepare_cb_once helper
 - sk-queue: Don't fail if we're dumping dead process queued creds (#PSBM-62778)
 - vz7: sk-queue -- Show the creds we're sending (#PSBM-64009)
 - vz7: sk-queue -- Show peers in hex form (#PSBM-64009)
 - vz7: seize -- Wait for seize in thawed state (#PSBM-63841)
 - vz7: freezer -- Add set_freezer_state helper (#PSBM-63841)
 - vz7: epoll -- Dont fail on dup'ed fd restore (#PSBM-63850)
 - vz7: dump: Any non-negative return code of run_scripts means an error (#PSBM-62583)
 - vz7: sk-unix -- Restore qlen before pushing queued data back (#PSBM-63762)
 - vz7: sockets: Separate socket buffer size setting into a helper (#PSBM-63762)
 - vz7: seize -- Show detached pid in freezer_detach
 - vz7: Show status of uninterruptable task (#PSBM-63211)
 - vz7: files -- Select proper master fd when collecting fd (#PSBM-63355)
 - vz7: pstree -- Introduce pstree_pid_cmp helper
 - vz7: page-xfer -- Handle partial splicing (#PSBM-63161)
 - vz7: ucred -- Drop packets from dead processes (#PSBM-62603)
 - vz7: epoll -- Use real file transferred for target fds check (#PSBM-62108)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (#PSBM-61095)
 - test: Add ucreds test
 - vz7: pagemap -- Use ssize_t type where appropriate (#PSBM-62199)
 - vz7: compel -- Use unsigned long for arguments (#PSBM-61961)
 - vz7: dump -- Set file limits back before fetching them into dump (#PSBM-61812)
 - vz7: Drop redundant comment
 - vz7: restore -- Lift up own file limits (#PSBM-63094)
 - vz7: Unlimit self RLIMIT_NOFILE resource for dump/predump (#PSBM-63002)
 - vz7: Unlimit and limit file number resource for c/r sake (#PSBM-61573)
 - vz7: kdat: Add fetching files stat
 - vz7: Don't forget to restore memory cgroup limits on pre-dupms (#PSBM-61534 #PSBM-53593)
 - vz7: Zap file size checking for "atop" (#PSBM-61459)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (#PSBM-61248)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (#PSBM-60643)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32
 - vz7: socket: don't restore ucred from kernel messages
 - vz7: netlink: dump/restore netlink options
 - vz7: netlink: restore queues and only then restore opts
 - vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly (#PSBM-60606 #PSBM-61459 #PSBM-61851)
 - vz7: mount -- Add lookup_first_fstype helper
 - vz7: criu: add more information about control messages (#PSBM-60643)
 - vz7: test: check ucred for netlink messages
 - vz7: netlink: dump and restore ucred-s for netlink messages (#PSBM-59339)
 - vz7: eventpoll: Skip inaccessible descriptors (#PSBM-60042)
 - vz7: pipes -- Restore pipe size via userns call (#PSBM-59829)
 - vz7: mount: fix mounting non-root shared mounts (#PSBM-55494)
 - vz7: test: pty05 -- Add testing of multiple devpts instance
 - vz7: tty -- Don't fail if @mnt_id is not present in images (#PSBM-60606)
 - vz7: tty: Fix devpts mounts resolving (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (#PSBM-58616)
 - vz7: tty: Save mount ids for terminals into image
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper
 - vz7: tty: Save task current terminal if present
 - vz7: Unlimit UBC when chekpointing (#PSBM-53593)
 - vz7: restore -- Enter destination veX once usernsd is up (#PSBM-56407)
 - vz7: Make get_dumpee_veid been exported
 - vz7: zdtm: check a netlink socket with in-kernel state
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
 - vz7: sk-inet: Fix lookup for raw sockets (#PSBM-55835)
 - vz7: shmem: skip zero pages
 - vz7: shmem: don't write zero pages into an image
 - vz7: seccomp -- Switch to prctl interface if syscall is not implemented (#PSBM-55593)
 - vz7: ghost files: don't check ghost size if it's an NFS path (#PSBM-56159)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED
 - vz7: test: Add simple socket-raw test
 - vz7: sk-inet: Add initial support for raw sockets (#PSBM-51614)
 - vz7: Don't use executable stacks in @syscall_ip (#PSBM-55989)
 - vz7: util: Add rmdirp helper
 - vz7: mount: handle error from restore_shared_options()
 - vz7: seize: Add additional diagnose messages (#PSBM-53929)
 - vz7: mount: bind-mount autofs mounts via a file descriptors (#PSBM-53194)
 - vz7: spfs: create control socket in /run/spfs-manager/<pid> (#PSBM-59199)
 - vz7: spfs: move SPFS manager to corresponding container's dump directory
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (#PSBM-52353)
 - vz7: mnt -- Fetch VEID from cgroup for migration sake (#PSBM-52372)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (#PSBM-52320)
 - vz7: cg: Don't dump devices.list (#PSBM-50551)
 - vz7: scripts: remove obsolete scripts
 - vz7: cr-restore: use spfs helpers to control spfs manager
 - vz7: spfs: add new helpers to replces bash scripts calls
 - vz7: files-reg: move ghost_apply_metadata out of create_ghost_dentry
 - vz7: mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - vz7: files-reg: fix silly-renamed files migration
 - vz7: files-reg: improve spfs_file helper
 - vz7: Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - vz7: files: Allow to dump ploopX files opened (#PSBM-49723)
 - vz7: spfs: remove obsolete code
 - vz7: files-reg: migrate "spfs" files as ghost-ones
 - vz7: files-reg: conditionally dump content in dump_ghost_file
 - vz7: util: mkdirname helper introduced
 - vz7: files-reg: split create_ghost
 - vz7: files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - vz7: dump: Show task comm early
 - vz7: spfs: do not tolerate file existence on creation
 - vz7: spfs: fix freeze cgroup path discovery
 - vz7: cgroup: new_cg_root_get helper introduced
 - vz7: criu: remove NFS unlinked files restriction
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects
 - vz7: files-reg: migrate spfs file as "link remap" objects
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - vz7: spfs: explicitly pass size and mode to spfs_create_file
 - vz7: link_remap: do not create excessive links for a single file
 - vz7: mount: forbid dumping overmounted NFS (#PSBM-48620)
 - vz7: zdtm: add a new test to check netlink sockets with queued data
 - vz7: netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages
 - vz7: check: check whether NETLINK_REPAIR is supported or not
 - vz7: netlink: request flags for netlink sockets
 - vz7: files-reg: forbid to dump unlinked NFS files
 - vz7: proc_parse: forbid dumping NFS remote locks
 - vz7: files-reg: remove "unreachable" protobuf field as redundant
 - vz7: files-reg: create spfs file in case of parent mount is SPFS
 - vz7: files-reg: do not create spfs file in case of external resource
 - vz7: spfs: remove "ns_list" option from "replace" command as obsolete
 - vz7: compel -- Add support for vz7 specific cpuid masking (#PSBM-47748 #PSBM-49423)
 - vz7: scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - vz7: scripts: restart all systemd automount services (#PSBM-46672)
 - vz7: sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - vz7: util: Add cr_set_root/cr_restore_root helpers
 - vz7: spfs: do not treat existent file as error in create_reg_file
 - vz7: scripts: spfs-release-replace.sh introduced
 - vz7: criu: spfs -- Fixup various nits for NFS sake
 - vz7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - vz7: mount: Add support for NFSv4
 - vz7: protobuf/mnt.proto: NFSv4 type added
 - vz7: mount: add support for NFS
 - vz7: protobuf/mnt.proto: NFS type added
 - vz7: mount: add support for SUNRPC Pipefs
 - vz7: protobuf/mnt.proto: RPC Pipefs type added
 - vz7: scripts: allow-nfs-ports.sh added
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added
 - vz7: scripts: spfs-change-mode.sh added
 - vz7: action scripts: set spfs environment in run_scripts
 - vz7: regular files: create temporary spfs file if marked as unreachable
 - vz7: spfs: delayed mounts facility introduced
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd
 - vz7: regular files: protobuf "unreachable" field introduced
 - vz7: filemap: collect mapped file fs type
 - vz7: reg_file_entry: add "mode" variable
 - vz7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - vz7: Wait aio pending requests (#PSBM-42488)
 - vz7: criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - vz7: Merge vanilla 3.0

* Thu May 04 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.49
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join (#PSBM-65483)

* Tue May 02 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.48
 - vz7: tty: Make sure no /dev/tty inheritance exist (#PSBM-65637)

* Thu Apr 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.47
 - vz7: fs: Populate opts.has_binfmt_misc on dump only (#PSBM-65367)

* Mon Apr 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.46
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (#PSBM-65185)

* Fri Apr 21 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.45
 - vz7: test: sk-unix01 -- Make sure the dir with ghost files are empty
 - vz7: sk-unix: Don't wait on socketpair (#PSBM-65051)
 - vz7: sk-unix -- Add info print about slave peers

* Wed Apr 19 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.44
 - vz7: sk-unix -- Adjust default dgram qlen for systemd sake (#PSBM-64628)
 - Revert "vz7: sockets: Separate socket buffer size setting into a helper"
 - Revert "vz7: sk-unix -- Restore qlen before pushing queued data back"
 - Revert "sk-queue: Queue length must be sync"

* Tue Apr 18 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.43
 - vz7: sk-unix -- Fix typo in namelen comparision (#PSBM-64715)
 - vz7: sk-queue: Add missing newline into log
 - vz7: restore_sk_queue -- Show how many bytes already sent
 - vz7: test: sk-unix01 -- Fix compilation

* Mon Apr 17 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.42
 - vz7: sk-unix: Don't append ghost postfix on subsequent checkpoint (#PSBM-55992)

* Thu Apr 13 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.41
 - Revert "unix: switch into the root mount namespace before cleaning stale sockets" (#PSBM-64369)

* Wed Apr 12 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.40
 - test: Add sk-unix01 test
 - vz7: sk-unix: Add ability to restore sockets with deleted vfs addresses (#PSBM-55992)
 - vz7: sk-unix: Print cwd been restored if @name_dir is present
 - vz7: sk-unix: Don't warn if nothing to unlink
 - vz7: sk-unix: Collect deleted identical addresses in the queues
 - vz7: sk-unix: Make USK_ flags in shift form
 - vz7: sk-unix: Drop empty line at eof
 - vz7: sk-unix: Use add_post_prepare_cb_once helper
 - vz7: sk-unix: Drop empty line
 - vz7: sk-unix: Use generic xptr_pull in dump_one_unix_fd
 - vz7: sk-unix: Use native types in unix_sk_info
 - vz7: sk-unix: Adjust unix_sk_info members
 - vz7: sk-unix: Adjust unix_sk_cinfo members
 - vz7: sk-unix: Make can_dump_unix_sk being boolean
 - vz7: pipes: Use add_post_prepare_cb_once
 - vz7: tty: Use add_post_prepare_cb_once
 - vz7: restore: Add add_post_prepare_cb_once helper
 - unix: a unix name can be a non-null terminated string
 - unix: Do pr_perror() before cleanup
 - files: Sanitize helpers for scattering two-headed files
 - unix: Factor out common parts restoration (v2)
 - unix: Fix tail processing for peer-less sockets
 - unix: don't leak a file descriptor
 - unix: switch into the root mount namespace before cleaning stale sockets
 - Revert "vz7: sk-unix: Restore deleted sockets together with removed dirs"

* Mon Apr 10 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.39
 - sk-queue: Don't fail if we're dumping dead process queued creds (#PSBM-62778)

* Mon Apr 10 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.38
 - sk-queue: Queue length must be sync (#PSBM-64009)
 - vz7: sk-queue -- Show the creds we're sending (#PSBM-64009)
 - vz7: sk-queue -- Show peers in hex form (#PSBM-64009)

* Fri Apr 07 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.37
 - vz7: seize -- Wait for seize in thawed state (#PSBM-63841)
 - vz7: freezer -- Add set_freezer_state helper (#PSBM-63841)
 - vz7: epoll -- Dont fail on dup'ed fd restore (#PSBM-63850)

* Thu Apr 06 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.36
 - vz7: dump: Any non-negative return code of run_scripts means an error (#PSBM-62583)

* Wed Apr 05 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.35
 - vz7: sk-unix -- Restore qlen before pushing queued data back (#PSBM-63762)
 - vz7: sockets: Separate socket buffer size setting into a helper (#PSBM-63762)
 - vz7: seize -- Show detached pid in freezer_detach

* Tue Apr 04 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.34
 - vz7: seize -- Make sure there is enough space for eol on debug print (#PSBM-63211)
 - vz7: Show status of uninterruptable task (#PSBM-63211)

* Mon Apr 03 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.33
 - vz7: files -- Select proper master fd when collecting fd (#PSBM-63355)
 - vz7: pstree -- Introduce pstree_pid_cmp helper
 - vz7: page-xfer -- Handle partial splicing (#PSBM-63161)

* Tue Mar 28 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.32
 - vz7: restore -- Lift up own file limits (#PSBM-63094)
 - vz7: Make rlimit_limit_nofile_self being global

* Mon Mar 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.31
 - vz7: Unlimit self RLIMIT_NOFILE resource for dump/predump (#PSBM-63002)
 - Revert "vz7: Increase the number of files limit"

* Fri Mar 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.30
 - vz: zdtm/mnt_ext_auto: add different bind-mounts of external mount (#PSBM-46753)
 - vz7: mount: migrate bindmounts of external mounts (#PSBM-46753)
 - vz7: mount: save ext_real_root for external mounts (#PSBM-46753)
 - vz7: mount: remove excess mi->external checks
 - vz7: mount: fix confusing naming

* Wed Mar 22 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.29
 - vz7: ucred -- Drop packets from dead processes (#PSBM-62603)

* Tue Mar 21 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.28
 - vz7: epoll -- Use real file transferred for target fds check (#PSBM-62108)
 - vz7: epoll: Report error instead of BUG (#PSBM-62108)

* Mon Mar 20 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.27
 - vz7: sk-queue -- Add support of ucreds in unix sockets (#PSBM-61095)
 - test: Add ucreds test

* Wed Mar 15 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.26
 - vz7: parasite-syscall -- Move rlimit_limit_nofile into parasite_cure_remote (#PSBM-62267)

* Tue Mar 14 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.25
 - vz7: spfs: create control socket in /run/spfs-manager/<pid> (#PSBM-59199)
 - vz7: pagemap -- Use ssize_t type where appropriate (#PSBM-62199)
 - pagemap: Support async pages reading by chunks (v2)

* Mon Mar 13 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.24
 - fsnotify: skip non-direcory mounts (#PSBM-57362)

* Mon Mar 13 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.23
 - test: Add shutdown'ed UDP socket test
 - sk-inet: Add support for shutdown'ed UDP/UDPlite sockets (#PSBM-61550)

* Fri Mar 10 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.22
 - vz7: parasite -- Use long for memory size (#PSBM-61961)
 - vz7: dump -- Set file limits back before fetching them into dump (#PSBM-61812)
 - vz7: parasite-syscall -- Export rlimit_[un]limit_nofile
 - vz7: Unlimit and limit file number for dump stage only (#PSBM-61812)

* Fri Mar 10 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.21
 - vz7: dump -- Set file limits back before fetching them into dump (#PSBM-61812)
 - vz7: parasite-syscall -- Export rlimit_[un]limit_nofile
 - vz7: Unlimit and limit file number for dump stage only (#PSBM-61812)

* Thu Mar 09 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.20
 - vz7: Unlimit and limit file number for dump stage only (#PSBM-61812)

* Thu Mar 09 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.19
 - vz7: Fix net_cls controllers transition (#PSBM-61851 #PSBM-60606)
 - vz7: Drop redundant comment
 - vz7: Drop debug leftover from 0a3713ab2c44f

* Tue Mar 07 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.18
 - vz7: Unlimit and limit file number resource for c/r sake (#PSBM-61573)
 - vz7: kdat: Add fetching files stat
 - vz7: parasite: Switch to map-files interface is memfd failed
 - vz7: memfd: Print detailed error if memfd_create failed
 - Revert "vz7: Dump only known controllers" (#PSBM-61768)

* Tue Mar 07 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.17
 - Revert "vz7: Dump only known controllers" (#PSBM-61768)

* Fri Mar 03 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.16
 - vz7: Don't forget to restore memory cgroup limits on pre-dupms (#PSBM-61534 #PSBM-53593)

* Fri Mar 03 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.15
 - vz7: Don't rename net_cls if no net_cls,net_prio present (#PSBM-60606 #PSBM-61459)
 - vz7: Zap file size checking for "atop" (#PSBM-61459)

* Wed Mar 01 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.14
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (#PSBM-61248)
 - vz7: restore_sk_queue -- Drop trailing tabs
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (#PSBM-61248)

* Wed Feb 22 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.13
 - vz7: systemd-autofs-restart.sh: fix issue with removed check_fs_type
reference (#PSBM-60980)
 - vz7: Fix type conversion in dump_packet_cmsg

* Sun Feb 19 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.12
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (#PSBM-60643)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32
 - vz7: socket: don't restore ucred from kernel messages
 - vz7: netlink: dump/restore netlink options
 - vz7: netlink: restore queues and only then restore opts

* Fri Feb 17 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.11
 - vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly (#PSBM-60606)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper

* Thu Feb 16 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.10
 - vz7: criu: add more information about control messages (#PSBM-60643)
 - docs: criu -- Explain pre-resume stage
 - action-scripts: Add "pre-resume" stage (#PSBM-58742)
 - Revert "vz7: Add ACT_POST_SIGRETURN"
 - vz7: Fix type conversion in dump_packet_cmsg

* Tue Feb 14 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.9
 - vz7: test: check ucred for netlink messages
 - vz7: netlink: dump and restore ucred-s for netlink messages (#PSBM-59339)

* Wed Feb 08 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.8
 - vz7: eventpoll: Skip inaccessible descriptors (#PSBM-60042)

* Fri Feb 03 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.7
 - vz7: pipes -- Restore pipe size via userns call (#PSBM-59829)

* Wed Feb 01 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.6
 - vz7: eventpoll: Fix dependency check (#PSBM-59550)

* Thu Jan 26 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.5
 - vz7: tty: Fix devpts mounts resolving (#PSBM-59223)
 - vz7: test: pty05 -- Extend test for unshared mount ns

* Thu Jan 26 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.4
 - vz7: files: Fix test and set endianess problem (#PSBM-58228)
 - vz7: tty: Optimize dependencies check
 - vz7: files: Merge collect_gen_fd() and collect_used_fd(), and call it
unconditionally
 - vz7: files: Kill pid parameter of open_fdinfos()
 - vz7: eventpoll: Use generic list for eventpoll files
 - vz7: tty: Use generic list for tty files
 - vz7: files: Move ctty fixup to open_fd()
 - vz7: tty: Set dependencies between masters, slaves and ctty
 - vz7: files: Kill struct file_desc_ops::post_open
 - vz7: files: Make recv_fd_from_peer() non-block
 - vz7: files: Add new_fd parameter to file_desc_ops::open()
 - vz7: files: Set fds event after sending fd to peer
 - vz7: eventpoll: Make post_open stage may fail
 - vz7: files: BUG on reopening already opened fle
 - vz7: timerfd: Kill post_open stage
 - vz7: inet: Use task_st futex for notification instead of per-port
 - vz7: inet: Link sockets in port_type list
 - vz7: unix: Wait a peer using task_st futex
 - vz7: unix: Link connected to peer sockets to its list
 - vz7: files: Add fdinfo_list_entry::stage
 - vz7: files: Implement {set,clear,wait}_fds_event()
 - vz7: bits: Add test_and_set_bit()
 - vz7: pstree: Add task_st bit field
 - vz7: headers: Move lock.h into include/common/
 - vz7: files: Merge states iteration into open_fdinfos()
 - vz7: files: Kill fd_open_state::receive_fd stage
 - vz7: files: Kill want_post_open_stage()
 - vz7: files: Kill fd parameter of transport_name_gen()
 - vz7: files: Kill file_desc_ops::want_transport()
 - vz7: files: Receive real fd numbers using recv_fd_from_peer()
 - vz7: files: Make sending fds to peers async
 - vz7: files: Allow to receive further fds
 - vz7: files: Add fle_init() for initialization new fdinfo_list_entry
 - vz7: files: Move derefferencing of TRANSPORT_FD_OFF to send_fd_to_peer()
 - vz7: files: Move closing fle's transport_fd to recv_fd_from_peer()
 - vz7: files: Send/receive fds with pointers on their struct fdinfo_list_entry
in receiver

* Wed Jan 25 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.3
 - pcs7: mount: fix mounting non-root shared mounts

* Mon Jan 23 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.2
 - vz7: test: pty05 -- Add testing of multiple devpts instance
 - vz7: tty: Add support for multiple devpts instances (#PSBM-58616)
 - vz7: tty: Save mount ids for terminals into image
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper
 - vz7: tty: Save task current terminal if present
 - vz7: tty: Print rdev and dev pair in case of error
 - vz7: tty: Unify id printing

* Mon Jan 23 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.1
 - vz7: Makefile.version -- Adjust number for new series
 - Rebase to vanilla criu v2.10

* Mon Jan 09 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.15
 - vz7: Unlimit UBC when chekpointing (#PSBM-53593)
 - vz7: restore -- Enter destination veX once usernsd is up (#PSBM-56407)
 - vz7: Add ACT_POST_SIGRETURN
 - vz7: Make get_dumpee_veid been exported
 - vz7: zdtm: check a netlink socket with in-kernel state
 - vz7: netlink: allow to dump netlink sockets with in-progress operations

* Thu Dec 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.14
 - pcs7: tcp: bind tcp sockets after enabling the repair mode (#PSBM-57413)
 - Revert "pcs7: tcp: bind tcp sockets after enabling the repair mode"

* Thu Dec 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.13
 - pcs7: tcp: bind tcp sockets after enabling the repair mode (#PSBM-57413)
 - pcs7: scripts: Print error value in case of action script fail

* Wed Dec 14 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.8.0.12-2
- Rebuild in 7.3 environment

* Tue Dec 13 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.12
 - pcs7: sk-inet: Fix lookup for raw sockets (#PSBM-55835)

* Tue Dec 13 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.11
 - zdtm: add a test to check a mount tree with overmounts (Andrei Vagin
<avagin@virtuozzo.com>)
 - mount: clone a mount namespace to open a detached mount (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-57135)
 - mnt: try to split a mount tree to restore over-mounted mounts (Andrei Vagin
<avagin@virtuozzo.com>)
 - mnt: rename roots_mp into root_yard_mp and make it global (Andrei Vagin
<avagin@virtuozzo.com>)
 - mnt: add a sub-id to print_ns_root (Andrei Vagin <avagin@virtuozzo.com>)
 - mnt: clean up (Andrei Vagin <avagin@virtuozzo.com>)
 - mnt: add a function to check whether a mount overmounts something (Andrei
Vagin <avagin@virtuozzo.com>)

* Fri Dec 09 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.10
 - pcs7: shmem: skip zero pages

* Fri Dec 09 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.9
 - pcs7: shmem: don't write zero pages into an image

* Thu Dec 08 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.8
 - pcs7: zdtm: check sequence numbers for tcp sockets
 - pcs7: build: install libnet-dev
 - pcs7: zdtm.py: pass a test PID into zdtm hooks
 - pcs7: zdtm: add test cases on TCP_SYN_SENT
 - pcs7: zdtm: add a test for unconnected tcp sockets
 - pcs7: zdmt: add more checks into socket-closed-tcp
 - pcs7: zdtm: check sockets in the TCP_CLOSING state
 - pcs7: zdtm: add test cases on TCP_CLOSE_WAIT and TCP_LAST_ACK states
 - pcs7: zdtm: add test cases on TCP_FIN_WAIT* states
 - pcs7: tcp: add support for synsent
 - pcs7: tcp: allow to dump intermediate closing states
 - pcs7: inet: dump source and destination addresses for closed sockets
 - pcs7: soccr: add support for syn-sent sockets
 - pcs7: soccr: add support for half-closed sockets
 - pcs7: soccr: move connect from criu to soccr
 - pcs7: soccr: add source and destination addresses to libsoccr_sk_data
 - pcs7: criu: check whether tcp_repair can be enabled for half-closed sockets
 - pcs7: soccr: add prefixes for log messages and print errno
 - pcs7: soccr: add '\n' to all loge/logd
 - pcs7: criu: enable soccr logging
 - pcs7: build: only generate soccr config.h if necessary
 - pcs7: soccr: Generate config.h dynamically
 - pcs7: soccr: rectify Alpine build
 - pcs7: make, soccr: let CRIU depend on libsoccr
 - pcs7: soccr: Add soccr.h's comments
 - pcs7: soccr: Handle connection state
 - pcs7: soccr/tcp: Restore queues using library
 - pcs7: soccr/tcp: Restore socket's info after binding it
 - pcs7: soccr/tcp: Restore socket's info before binding it
 - pcs7: soccr/tcp: Prepare connection info for restore
 - pcs7: soccr/tcp: Read queues contents using library
 - pcs7: soccr/tcp: Fill actual connection info using the library
 - pcs7: soccr/tcp: Introduce blob with connection info and getter for it
 - pcs7: soccr/tcp: Add _pause and _resume to library and use it
 - pcs7: soccr: Add logging
 - pcs7: soccr: Wire into builder
 - criu.spec: Add libnet-devel requirement for tcp-close sake

* Wed Dec 07 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.7
 - pcs7: seccomp -- Switch to prctl interface if syscall is not implemented (#PSBM-55593)

* Wed Dec 07 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.6
 - pcs7: restore: Fetch mmap_minimal_address runtime (#PSBM-56797)

* Mon Dec 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.5
 - pcs7: ghost files: don't check ghost size if it's an NFS path (#PSBM-56159)

* Thu Dec 01 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.4
 - pcs7: criu: Fix open() retval analysing (#PSBM-56384)

* Thu Dec 01 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.3
 - pcs7: fs: Fix retval analysing erratum (#PSBM-56384)

* Wed Nov 30 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.2
 - pcs7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED

* Wed Nov 30 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.1
 - pcs7: Adjust version for 2.8 series
 - Rebase to vanilla CRIU-2.8 series

* Mon Nov 28 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.23
 - pcs7: test: Add simple socket-raw test
 - pcs7: sk-inet: Add initial support for raw sockets (#PSBM-51614)

* Fri Nov 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.22
 - pcs7: Don't use executable stacks in @syscall_ip (#PSBM-55989)
 - Revert "pcs7: criu: proc_parse -- Add guard page the same way as kernel
detects them"
 - Revert "pcs7: parasite: Don't try to start executing syscall from guard page"

* Fri Nov 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.21
 - pcs7: parasite: Don't try to start executing syscall from guard page (#PSBM-55989)
 - pcs7: criu: proc_parse -- Add guard page the same way as kernel detects them (#PSBM-55989)

* Wed Nov 23 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.20
 - pcs7: test: Add del_standalone_un_dentry test
 - pcs7: sk-unix: Restore deleted sockets together with removed dirs (#PSBM-55495)
 - pcs7: util: Add rmdirp helper
 - pcs7: test: rmdir_open -- Delete two levels of directories
 - pcs7: criu: files-reg -- Create a complete path to delete dentry
 - pcs7: util: Make mkdirpat more generic

* Tue Nov 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.19
 - pcs7: mount: don't create a temporary directory if /tmp exists
 - ps7: mount: fix mounting non-root shared mounts (#PSBM-55494)
 - pcs7: mount: handle error from restore_shared_options()

* Tue Oct 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.18
 - seize: Add additional diagnose messages (#PSBM-53929)

* Sun Oct 16 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.17
 - pcs7: mount: bind-mount autofs mounts via a file descriptors (#PSBM-53194)

* Tue Oct 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.16
 - pcs7: Fix seize_cgroup_tree error code collide

* Sun Oct 09 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.15
 - pcs7: freeze -- Wait for exiting tasks to complete (#PSBM-53282)

* Thu Oct 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.14
 - pcs7: scripts -- systemd-autofs-restart.sh: explicitly return result from
get_fs_type (#PSBM-53239)

* Thu Sep 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.13
 - pcs7: spfs: move SPFS manager to corresponding container's dump directory

* Tue Sep 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.12
 - pcs7: mount: Correct s_dev conversion in mount_cr_time_mount() (#PSBM-52460)

* Mon Sep 26 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.11
 - pcs7: mount: Set opts.has_binfmt_misc regardless of mnt_ns level (#PSBM-52513)

* Sat Sep 24 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.10
 - pcs7: mount: Move adding cr-time binfmt_misc to collect_mnt_namespaces() (#PSBM-52513)
 - pcs7: mount: Do not fail on shared cr-time mounts mismatch (#PSBM-52513)

* Fri Sep 23 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.9
 - pcs7: restorer: add forgotten CLONE_FS flag for threads clone (#PSBM-47623)

* Thu Sep 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.8
 - pcs7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (#PSBM-52353)
 - pcs7: mnt -- Fix case where ve cgroup not found

* Thu Sep 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.7
 - pcs7: mnt -- Fetch VEID from cgroup for migration sake (#PSBM-52372)

* Thu Sep 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.6
 - pcs7: mount: Corrent sibling path when parent and child have the same
mountpoint (#PSBM-52346)

* Mon Sep 19 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.5
 - pcs7: mount: Enter/exit VE while mounting CR-time binfmt_misc (#PSBM-52320)

* Fri Sep 16 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.4
 - mount: Prohibit second binfmt_misc superblock (#PSBM-47737)
 - mount: Restore binfmt_misc content in case of missing mount
 - mount: Forced mount unmounted binfmt_misc to do not lost its content
 - mount: Autodetect binfmt_misc
 - mount: Create binfmt_misc image w/o device suffix
 - mount: Move binfmt_misc entry restore code to subfunction
 - mount: Collect new type binfmt_misc.img image entries
 - image: Rename binfmt_misc image format as "old"
 - pcs7: shmem -- Inspect pages before the dump (#PSBM-52138)

* Mon Aug 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.3
 - pcs7: systemd-autofs-restart.sh: fix error handling in case of system
limitation (#PSBM-51299)

* Fri Aug 26 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.2
 - seize: collect_pstree -- Add missing error sign return (#PSBM-51428)

* Thu Aug 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.1
 - pcs7: Adjust version for v2.5.x.x series
 - pcs7: conflict resolve
 - pcs7: scritps: systemd-autofs-restart.sh -- Do not treat absence on bindmount
as error (#PSBM-50684)
 - pcs7: cg: Don't dump devices.list (#PSBM-50551)
 - unix: don't drop the path on unix sockets if they don't exist (Dmitry Safonov
<dsafonov@virtuozzo.com>)
 - pcs7: Increase the number of files limit (#PSBM-46761 #PSBM-50607)
 - pcs7: scripts: remove obsolete scripts
 - pcs7: cr-restore: use spfs helpers to control spfs manager
 - pcs7: spfs: add new helpers to replces bash scripts calls
 - pcs7: files-reg: move ghost_apply_metadata out of create_ghost_dentry
 - pcs7: Lift up local version
 - pcs7: Dump only known controllers (#PSBM-46382)
 - pcs7: log: Print version into the log (#PSBM-50239)
 - pcs7: mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - pcs7: files-reg: fix silly-renamed files migration
 - pcs7: files-reg: improve spfs_file helper
 - pcs7: mount: sysfs -- Use slave mounting for the root (#PSBM-50010)
 - pcs7: util-vdso: correct vdso symbol's length
 - pcs7: Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - pcs7: files: Allow to dump ploopX files opened (#PSBM-49723)
 - pcs7: spfs: remove obsolete code
 - pcs7: files-reg: migrate "spfs" files as ghost-ones
 - pcs7: files-reg: conditionally dump content in dump_ghost_file
 - pcs7: util: mkdirname helper introduced
 - pcs7: files-reg: split create_ghost
 - pcs7: files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - pcs7: seize: Wait the freezer to complete before processing tags (#PSBM-49439)
 - pcs7: dump: Move task_comm_info helpers into seize.c
 - pcs7: spfs: do not tolerate file existence on creation
 - pcs7: dump: Show task comm early
 - pcs7: spfs: add device files creation support (#PSBM-48985)
 - pcs7: spfs: fix freeze cgroup path discovery
 - pcs7: cgroup: new_cg_root_get helper introduced
 - pcs7: criu: remove NFS unlinked files restriction
 - pcs7: files-reg: migrate spfs unlinked file as "link remap" objects
 - pcs7: files-reg: migrate spfs file as "link remap" objects
 - pcs7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - pcs7: spfs: explicitly pass size and mode to spfs_create_file
 - pcs7: link_remap: do not create excessive links for a single file
 - pcs7: proc_parse: fix vma file open mode recognition (#PSBM-49199)
 - pcs7: log: files-ext -- Show exactly which file can't be dumped
 - pcs7: criu: util -- Add __read_fd_link helper
 - pcs7: mount: forbid dumping overmounted NFS (#PSBM-48620)
 - pcs7: zdtm: add a new test to check netlink sockets with queued data
 - pcs7: netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - pcs7: sk-queue: add an ability to dump addresses for messages
 - pcs7: check: check whether NETLINK_REPAIR is supported or not
 - pcs7: netlink: request flags for netlink sockets
 - pcs7: files-reg: forbid to dump unlinked NFS files
 - pcs7: proc_parse: forbid dumping NFS remote locks
 - pcs7: files-reg: remove "unreachable" protobuf field as redundant
 - pcs7: files-reg: create spfs file in case of parent mount is SPFS
 - pcs7: files-reg: do not create spfs file in case of external resource
 - pcs7: spfs: remove "ns_list" option from "replace" command as obsolete
 - pcs7: namespace: mark mount namespaces as populated after the forking stage (#PSBM-48222)
 - pcs7: arch, x86 -- Add support for vz7 specific cpuid masking (#PSBM-47748 #PSBM-49423)
 - pcs7: scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - pcs7: scripts: restart all systemd automount services (#PSBM-46672)
 - pcs7: sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - pcs7: util: Add cr_set_root/cr_restore_root helpers
 - pcs7: spfs: do not treat existent file as error in create_reg_file
 - pcs7: seize: Take --timeout option into account when freezing processes (#PSBM-47539 #PSBM-47538)
 - pcs7: scripts: spfs-release-replace.sh introduced
 - pcs7: criu: spfs -- Fixup various nits for NFS sake
 - pcs7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - pcs7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - pcs7: mount: add support for NFSv4
 - pcs7: protobuf/mnt.proto: NFSv4 type added
 - pcs7: mount: add support for NFS
 - pcs7: protobuf/mnt.proto: NFS type added
 - pcs7: mount: add support for SUNRPC Pipefs
 - pcs7: protobuf/mnt.proto: RPC Pipefs type added
 - pcs7: scripts: allow-nfs-ports.sh added
 - pcs7: action-scripts: ACT_POST_NET_LOCK stage added
 - pcs7: scripts: spfs-change-mode.sh added
 - pcs7: action scripts: set spfs environment in run_scripts
 - pcs7: regular files: create temporary spfs file if marked as unreachable
 - pcs7: spfs: delayed mounts facility introduced
 - pcs7: cr-restore: declare SPFS_MNGR_SK service fd
 - pcs7: regular files: protobuf "unreachable" field introduced
 - pcs7: filemap: collect mapped file fs type
 - pcs7: reg_file_entry: add "mode" variable
 - pcs7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - pcs7: Wait aio pending requests (#PSBM-42488)
 - pcs7: criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - pcs7: Initial sync with vanilla v2.4
 - log: Print version into the log (#PSBM-50239)
 - files-reg: fix silly-renamed files migration
 - files-reg: improve spfs_file helper
 - mounts: export is_root_mount helper
 - Revert "sk-unix: forbid to dump NFS unix sockets" (#PSBM-47017)
 - mount: sysfs -- Use slave mounting for the root (#PSBM-50010)
 - util-vdso: correct vdso symbol's length
 - Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - files: Allow to dump ploopX files opened (#PSBM-49723)
 - version: Adjust numbering
 - Revert "files_reg: carry rdev with regular files"
 - seize: Wait the freezer to complete before processing tags (#PSBM-49439)
 - spfs: remove obsolete code
 - files-reg: migrate "spfs" files as ghost-ones
 - files-reg: conditionally dump content in dump_ghost_file
 - util: mkdirname helper introduced
 - files-reg: split create_ghost
 - files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - dump: Move task_comm_info helpers into seize.c
 - pcs7: arch, x86 -- Fix typo in cpuid masking code (#PSBM-49423)
 - spfs: do not tolerate file existence on creation
 - dump: Show task comm early
 - spfs: add device files creation support (#PSBM-48985)
 - files_reg: carry rdev with regular files
 - spfs: fix freeze cgroup path discovery
 - cgroup: new_cg_root_get helper introduced
 - criu: remove NFS unlinked files restriction
 - files-reg: migrate spfs unlinked file as "link remap" objects
 - files-reg: migrate spfs file as "link remap" objects
 - spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - spfs: explicitly pass size and mode to spfs_create_file
 - link_remap: do not create excessive links for a single file
 - cr-dump: discover fs type in fill_fd_params_special
 - proc_parse: fix vma file open mode recognition (#PSBM-49199)
 - tty: Don't forget to add eol when inverting slave pts paths (#PSBM-49008)
 - tty: Fix typos in vt driver choosing (#PSBM-48614)
 - mount: don't do MS_REC|MS_PRIVATE for host mounts (#PSBM-46298)
 - log: files-ext -- Show exactly which file can't be dumped
 - criu: util -- Add __read_fd_link helper
 - mount: forbid dumping overmounted NFS (#PSBM-48620)
 - zdtm: add a new test to check netlink sockets with queued data
 - netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - netlink: request flags for netlink sockets
 - sk-queue: add an ability to dump addresses for messages
 - check: check whether NETLINK_REPAIR is supported or not
 - unix: Do not autobind unnamed unix sockets (#PSBM-48446)
 - pcs7: images: Sync format with vanilla criu (#PSBM-48283)
 - sk-unix: forbid to dump NFS unix sockets
 - files-reg: forbid to dump unlinked NFS files
 - proc_parse: forbid dumping NFS remote locks
 - files-reg: remove "unreachable" protobuf field as redundant
 - files-reg: create spfs file in case of parent mount is SPFS
 - files-reg: do not create spfs file in case of external resource
 - spfs: remove "ns_list" option from "replace" command as obsolete
 - rpc: Implement @timeout interface (#PSBM-48256)
 - namespace: mark mount namespaces as populated after the forking stage (#PSBM-48222)
 - rpc: Add interface --freeze-cgroup option (#PSBM-44613)
 - pcs7: arch, x86 -- Add support for vz7 specific cpuid masking (#PSBM-47748)
 - dump: Allocate root_item before run pre-dump scripts (#PSBM-47737)
 - scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - net/sysctl: fix ipv4 forwarding (#PSBM-47355)
 - scripts: terminate systemd-autofs-restart.sh if saved mountpoint is missing (#PSBM-44207)
 - scripts: return non zero if save_mountpoint() fails (#PSBM-44207)
 - scripts: remove bogus command substitution in systemd-autofs-restart.sh (#PSBM-44207)
 - scripts: detect EOF on read in a usual way in systemd-autofs-restart.sh (#PSBM-44207)
 - mount: don't add a separate entry for each enabled file systems
 - scripts: restart all systemd automount services (#PSBM-46672)
 - sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - util: Add cr_set_root/cr_restore_root helpers
 - zdtm/ptrace_sig: don't print from signal handlers (#PSBM-47772)
 - test: file_locks01 -- Test for dev change if only env is set (#PSBM-47714)
 - test: fanotify00 -- Test for device change if only env set
 - test: static, fanotify00 -- Don't compare @s_dev in test (#PSBM-47667)
 - spfs: do not treat existent file as error in create_reg_file
 - seize: Take --timeout option into account when freezing processes (#PSBM-47539 #PSBM-47538)
 - mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - build: Don't forget to relink arch builtins on change
 - scripts: spfs-release-replace.sh introduced
 - Revert "scripts: spfs-release-replace.sh introduced"
 - scripts: spfs-release-replace.sh introduced
 - scripts: call readlink in CT context in systemd-autofs-restart.sh
 - scripts: single style for command substitution in systemd-autofs-restart.sh (#PSBM-44207)
 - tty: Don't forget to unblock tty peers
 - tty: Save @flags unconditionaly for consistency
 - zdtm: check in-flight data in ttys
 - tty: Write unread pty buffers on post dump stage (#PSBM-41399)
 - criu: don't interrupt do_new_mount() after appling mount options (#PSBM-47489)
 - aio: Consider AIO pages as "should be dumped" (#PSBM-47489)
 - test/sockets: add test for shut down stream unix sockets (#PSBM-47023)
 - sk-unix: ignore shutdown mismatch in unix sockets
 - scripts: fix strings comparison in systemd-autofs-restart.sh
 - net/sysctl: zero-init stable_secret strings (#PSBM-30942)
 - net/sysctl: remove excess type conversions for sysctl_entry.type
 - net/sysctl: silence read error in case of CTL_FLAGS_READ_EIO_SKIP
 - zdtm/net/ipv6: add test for string stable_secret
 - sysctl: fix allocation for array of pointers
 - zdtm/net/ipv6: add test for confs
 - zdtm/net/ipv6: add devconfs6 and rand_range6
 - zdtm/net/ipv6: allow inacurate match for mldvX_unsolicited_report_interval
 - zdtm/net/ipv4: split save_and_set and check_and_restore
 - zdtm/net/ipv4: replace rand limits with rand ranges
 - zdtm/net/ipv4: make save_and_set and check_and_restore reusable
 - restore/net/ipv6: net device and def/all configuration
 - dump/net/ipv6: net device and def/all configuration
 - net/ipv6: add devconfs6 array to store config option's names
 - net/ipv6/protobuf: add device config options for ipv6
 - net/ipv4: add net_conf_op to reuse for ipv6
 - protobuf: add SysctlEntry for ipv4/ipv6 sysctl confs or some others
 - sysctl: add CTL_FLAGS_HAS to mark successful sysctl_op request
 - zdtm/net/ipv4: rename devconfs4 and rand_limit4 and dir4
 - net/ipv4: suffix devconfs with "4"
 - net/ipv4: add new sysctls
 - pcs7: criu: spfs -- Fixup various nits for NFS sake
 - pcs7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - pcs7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - pcs7: mount: add support for NFSv4
 - pcs7: protobuf/mnt.proto: NFSv4 type added
 - pcs7: mount: add support for NFS
 - pcs7: protobuf/mnt.proto: NFS type added
 - pcs7: mount: add support for SUNRPC Pipefs
 - pcs7: protobuf/mnt.proto: RPC Pipefs type added
 - pcs7: scripts: allow-nfs-ports.sh added
 - pcs7: action-scripts: ACT_POST_NET_LOCK stage added
 - pcs7: scripts: spfs-change-mode.sh added
 - pcs7: action scripts: set spfs environment in run_scripts
 - pcs7: regular files: create temporary spfs file if marked as unreachable
 - pcs7: spfs: delayed mounts facility introduced
 - pcs7: cr-restore: declare SPFS_MNGR_SK service fd
 - pcs7: regular files: protobuf "unreachable" field introduced
 - pcs7: filemap: collect mapped file fs type
 - pcs7: reg_file_entry: add "mode" variable
 - pcs7: cgroup: Fix early update of @dir_name in rewrite_cgsets (#PSBM-46987)
 - plugins: Initialize plugins control by default
 - pcs7: mount: add support for external block devices (#PSBM-39381)
 - pcs7: aio: Fix mmap retval analysing
 - pcs7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - pcs7: Wait aio pending requests (#PSBM-42488)
 - mount: create a clean mount only if a sub directory is bind-mounted (#PSBM-46908)
 - mount: dump a file system only if a mount point isn't overmounted (#PSBM-46908)
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46908)
 - Revert "mount: dump a file system only if a mount point isn't overmounted"
 - Revert "mount: don't overmount a mount if it should be bind-mounted
somewhere"
 - scripts: fix mountinfo parsing in systemd-autofs-restart.sh (#PSBM-46889)
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46732 #PSBM-46662)
 - mount: remove an extra condition from mounts_equal()
 - mount: handle a case when parent and child mounts in the same directory
 - mount: dump a file system only if a mount point isn't overmounted
 - Revert "mount: don't overmount a mount if it should be bind-mounted
somewhere" (#PSBM-46732)
 - autofs: support of "hidden" catatonic mounts (#PSBM-46572)
 - autofs: rework pipe search logic a bit
 - build: Add ability to generate gprof output
 - pcs7: scripts -- Make sure -1 pid is not passed (#PSBM-46572)
 - pcs7: Increase the number of files limit (#PSBM-46761)
 - scripts: do not use stat to discover fs type in systemd-autofs-restart.sh (#PSBM-46756)
 - scripts: save and restore target mount for autofs service (#PSBM-46672)
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46662)
 - pcs7: Dump only known controllers (#PSBM-46382)
 - Revert "cg: Add ability to dump predefined controllers only"
 - Revert "pcs7: Increase the number of files limit"
 - criu: dump filemap as soon as possible (#PSBM-46355)
 - autofs: collect new pipe fd as used (#PSBM-46601)
 - autofs: do not create dentries for indirect mount on bind-mounts (#PSBM-46572)
 - pcs7: Increase the number of files limit (#PSBM-46355)
 - build: install -- Don't forget to init DESTDIR
 - scripts: fix typo in binary path in systemd-autofs-restart.sh
 - restore: Wait for userns being prepared before moving into cgroups (v3)
 - Revert "restore: Wait for userns being prepared before moving into cgroups
(v2)"
 - cg: Add ability to dump predefined controllers only (#PSBM-46382)
 - scripts: join pid namespace in systemd-autofs-restart.sh (#PSBM-46470)
 - files: try to change fsuid only if linkat() failed (#PSBM-46201)
 - criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - restore: Wait for userns being prepared before moving into cgroups (v2) (#PSBM-46360)
 - Revert "restore: Wait for userns being prepared before moving into cgroups"
 - autofs: use temporary value for virtual pgrp on dump
 - restore: Wait for userns being prepared before moving into cgroups (#PSBM-46360)
 - files: Correctly handle tasks with no open file descriptors (#PSBM-46269)
 - autofs: install -- Fix libexec prefix (#PSBM-46249)
 - autofs: install -- Ship scripts/systemd-autofs-restart.sh (#PSBM-46249)
 - pcs7: Update Makefile.local
 - criu: action-scripts -- Don't access @root_item_pid if not present
 - zdtm: check the mem_dirty_track if --pre or --snap is set (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - ppc64le: fix build with UFFD (Pavel Emelyanov <xemul@virtuozzo.com>)
 - Fix compilation of action-scripts.c (Pavel Emelyanov <xemul@virtuozzo.com>)
 - kdat: Remove tcp_max_rshare (Pavel Emelyanov <xemul@virtuozzo.com>)
 - tcp: Send as much as possible (Pavel Emelyanov <xemul@virtuozzo.com>)
 - join-ns: Fix join-ns zdtm test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - sk: handle erorors of lseek (Pavel Emelyanov <xemul@virtuozzo.com>)
 - util: don't leak a socket (Pavel Emelyanov <xemul@virtuozzo.com>)
 - namespaces: don't leak memory on error paths (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: set NS_PID environment variable before "post-resume" hook (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - scripts: systemd-autofs-restart.sh added (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - build: Add export of sublevels and extra (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - build: compel -- Drop double targeting (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: "post-resume" hook introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - criu: opts -- Shuffle init_opts order (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: Drop config.h from deps (Pavel Emelyanov <xemul@virtuozzo.com>)
 - ns: Options join-ns and unshare are conflicting (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - compel: Initial commit for standalone tool (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - compel: piegen -- Introduce actions (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: piegen -- Add @arch option (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: piegen -- Add @uapi-dir option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - join-ns: add join-ns zdtm test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - join-ns: perform join_namespace according to join-ns opts (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - join-ns: add join-ns option to criu CLI and RPC (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd: add handling of zero pages (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: introduce uffd_handle_page (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: increment uffd_copied_pages only in one place (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: move the code out of the 'main' function (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: make some variable static global (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: move code into subfunctions (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd.c: remove unused variable vma_size (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked opts in autofs_mount (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked info in autofs_mount on error path (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked AutofsEntry in autofs_dump_entry (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: do not close NULL image (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: remove handling of VDSO pages (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: do not treat VDSO pages as lazy (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: Fix pr_debug format for vma start (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: fix device id modifier on error path in autofs_mnt_open (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - autofs: fix device id printf modifier on error path in autofs_mnt_open (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - autofs: do not treat old kernel as error in autofs_parse() (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: include limit.h before auto_fs.h (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: fix build on Fedora 22 (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd.c: do not call unneeded functions (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: move add_ns_shared_cb declaration to include/namespaces.h (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - Fix userfaultfd code with newer compilers (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - check: "autofs" feature added (Pavel Emelyanov <xemul@virtuozzo.com>)
 - zdtm.py: create "dev/autofs" root contruction (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: add autofs test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - mount: create target directory for AutoFS indirect mounts. (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: restore stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - autofs: declare ioctl helpers and constants (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pipes: export collect_one_pipe_ops() helper (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - files: new dup_fdinfo() and dup_fle() helpers introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - files: new "used" files list introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: dump fsinfo stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - autofs: parse fsinfo stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - protobuf: autofs entry introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - devices: add support for /dev/autofs (Pavel Emelyanov <xemul@virtuozzo.com>)
 - protobuf/mnt.proto: AutoFS type added (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Check private remount error code (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - unshare: Define UNSHARE_MOUNT_PROC constant (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: try to find a free pid between busy pids (v2) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: use rbtree to find a specified pid (v3) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: prepare to store all pid-s in rb-tree (v3) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: split alloc_pstree_helper (Pavel Emelyanov <xemul@virtuozzo.com>)
 - pstree: move state from pstree_item to pid (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Try to include userfaultfd with criu (part 2) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Try to include userfaultfd with criu (part 1) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Remove static from prepare_task_entries function (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Make skip_pages function available criu-wide (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - unshare: Support pidns (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Mount new proc (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Support mntns (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Preparations and CLI option (Pavel Emelyanov <xemul@virtuozzo.com>)
 - pcs7: Extend version output via local build (#PSBM-45009)
 - build: criu -- Don't forget to cleanup arch directory
 - cg: Add rollback in get_cg_set (#PSBM-45553)
 - cg: Add rollback for add_cgroup (#PSBM-45553)
 - cg: Fix use-after-free in put_ctls (#PSBM-45553)
 - pie: open_detach_mount -- Use pr_perror for regular build
 - util: return aligned pointers from shmalloc()
 - Makefile: drop 'rebuild' from help message
 - nmk: build.mk -- Add @libso-y helper
 - nmk: build.mk -- Add @hostprogs-y mode
 - nmk: msg.mk -- Add host- messages
 - nmk: build.mk -- Shrink gen-cc-rules
 - nmk: build.mk -- Drop any-match rule
 - nmk: build.mk -- Fix deps for target mode
 - nmk: build.mk -- Squash gen-rule-x into gen-cc-rules
 - nmk: Drop rules.mk
 - nmk: rules.mk -- Fix AFLAGS typo
 - tests: remap_dead_pid[_root] -- Run in namespace only
 - log: add gnu-styled output to stdout
 - build: images -- Add missing cleanups
 - namespaces: zero struct ns_id when allocating
 - criu: use strsignal to describe kill reason
 - nmk: build.mk -- Fix ar rule for external libs
 - nmk: build.mk -- Make process depend on Makefile itself
 - nmk: build.mk -- On cleanup use cleanup-y only
 - nmk: utils.mk -- Add cleanify helper
 - nmk: utils.mk -- Drop redundant spaces
 - nmk: build.mk -- Fix typo in gen-ar-target-rule
 - nmk: rules.mk -- Add per-obj flags
 - nmk: build.mk -- Drop unused objlist target
 - nmk: rules.mk -- Drop @CFLAGS_ and @ASFLAGS_ but add ability to bring them
via param
 - build: add mrproper target
 - build/nmk: add mrproper-y
 - build: Drop @images
 - nmk: scritps/macro.mk -- Enhance gen-built-in
 - x86/restorer: drop unused struct pt_regs
 - types: Remove setns override with sys_setns
 - rst-malloc: adjust free_bytes in rst_mem_align_cpos
 - netfilter: add -n to iptables and ip6tables calls
 - build: docs -- Use autogenerated footer
 - pstree: try to find a free pid between busy pids (v2)
 - pstree: use rbtree to find a specified pid (v3)
 - pstree: prepare to store all pid-s in rb-tree (v3)
 - pstree: split alloc_pstree_helper
 - pstree: move state from pstree_item to pid
 - criu: seize -- Don't left dangling @processes_to_wait_pids pointer
 - libnetlink: back port a fix for nlattr_parse()
 - netlink: Use nlattr instead of rtattr
 - criu: pstree_switch_state -- Fix nil deref on error path
 - irmap: use kdev everywere
 - dump: check for conflicts with the dead processes
 - irmap: don't try to dereference a null pointer
 - mounts: handle device numbers in different formats properly
 - criu: Use __NR_memfd_create for testing memfd presence
 - build: Conditionally defined SYS_* constants
 - build: criu -- Don't link with syscalls library
 - mount: don't use a shared mount to get a clean mount
 - mount: master_id should be 0 for new mounts
 - mount: restore a shared group for propagated mounts
 - build: clean up various other bits
 - build: Add verbose message on packages needed for CRIU building
 - build: Unify phony forms usage
 - pre-dump: don't waste time in error cases
 - dump: pre-dump should never kill processes
 - make: Improve tar generation
 - pcs7: Update local version
 - dump: don't call rollback actions from a signal handler (#PSBM-44371)
 - mounts: Skip already bound siblings in propagate_siblings()
 - PCS7: cgroup: Always restore predefined VE props (#PSBM-41406)
 - files-reg: Fix rm_parent_dirs() counter
 - files-reg: Delete ghost file numeric index
 - files-reg: Revert: Make try_clean_ghost() use struct ghost_file ptr
 - zdtm: Disable unlink_regular00 by default
 - zdtm: Add unlink_regular00 test
 - files-reg: Recreate deleted parent directories during restore of ghost file
 - files-reg: Create ghost files in first existing parent directory
 - files-reg: Move applying ghost file metadata from create_ghost() to separate
function
 - files-reg: Make try_clean_ghost() use struct ghost_file ptr
 - files-reg: Refactor create_ghost()
 - seize: detach from external processes before killing dumped processes (v2) (#PSBM-43795)
 - mount: separate private remount conditions for external and non-external (#PSBM-42829)
 - plugin: Add PRE_DUMP stage into plugins
 - dump: save master_id for the root mount (#PSBM-43260)
 - crtools: describe the inherit-fd option
 - parasite: Don't left memfd opened inside dumpee (#PSBM-43199)
 - scripts: post-setup-namespaces
 - seize: remove extra \n from the error message (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: don't detach from a task if a freezer cgroup is set (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: detach from all processes before waiting the root task (Cyrill
Gorcunov <gorcunov@openvz.org>) (#PSBM-43089)
 - make: Add Makefile.version (Cyrill Gorcunov <gorcunov@openvz.org>)

* Fri Aug 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.6
 - pcs7: scritps: systemd-autofs-restart.sh -- Do not treat absence on bindmount
as error (#PSBM-50684)

* Fri Aug 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.5
 - pcs7: cg: Don't dump devices.list (#PSBM-50551)

* Thu Aug 04 2016 Dmitry Safonov <dsafonov@virtuozzo.com> 2.4.0.4
 - unix: don't drop the path on unix sockets if they don't exist

* Wed Aug 03 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.3
 - pcs7: Increase the number of files limit (#PSBM-50607)
 - pcs7: scripts: remove obsolete scripts
 - pcs7: cr-restore: use spfs helpers to control spfs manager
 - pcs7: spfs: add new helpers to replces bash scripts calls

* Tue Aug 02 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.2
 - pcs7: files-reg: move ghost_apply_metadata out of create_ghost_dentry

* Tue Aug 02 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.1
 - pcs7: Lift up local version
 - pcs7: Dump only known controllers (#PSBM-46382)
 - pcs7: log: Print version into the log (#PSBM-50239)
 - pcs7: mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - pcs7: files-reg: fix silly-renamed files migration
 - pcs7: files-reg: improve spfs_file helper
 - pcs7: mount: sysfs -- Use slave mounting for the root (#PSBM-50010)
 - pcs7: util-vdso: correct vdso symbol's length
 - pcs7: Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - pcs7: files: Allow to dump ploopX files opened (#PSBM-49723)
 - pcs7: spfs: remove obsolete code
 - pcs7: files-reg: migrate "spfs" files as ghost-ones
 - pcs7: files-reg: conditionally dump content in dump_ghost_file
 - pcs7: util: mkdirname helper introduced
 - pcs7: files-reg: split create_ghost
 - pcs7: files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - pcs7: seize: Wait the freezer to complete before processing tags (#PSBM-49439)
 - pcs7: dump: Move task_comm_info helpers into seize.c
 - pcs7: spfs: do not tolerate file existence on creation
 - pcs7: dump: Show task comm early
 - pcs7: spfs: add device files creation support (#PSBM-48985)
 - pcs7: spfs: fix freeze cgroup path discovery
 - pcs7: cgroup: new_cg_root_get helper introduced
 - pcs7: criu: remove NFS unlinked files restriction
 - pcs7: files-reg: migrate spfs unlinked file as "link remap" objects
 - pcs7: files-reg: migrate spfs file as "link remap" objects
 - pcs7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - pcs7: spfs: explicitly pass size and mode to spfs_create_file
 - pcs7: link_remap: do not create excessive links for a single file
 - pcs7: proc_parse: fix vma file open mode recognition (#PSBM-49199)
 - pcs7: log: files-ext -- Show exactly which file can't be dumped
 - pcs7: criu: util -- Add __read_fd_link helper
 - pcs7: mount: forbid dumping overmounted NFS (#PSBM-48620)
 - pcs7: zdtm: add a new test to check netlink sockets with queued data
 - pcs7: netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - pcs7: sk-queue: add an ability to dump addresses for messages
 - pcs7: check: check whether NETLINK_REPAIR is supported or not
 - pcs7: netlink: request flags for netlink sockets
 - pcs7: files-reg: forbid to dump unlinked NFS files
 - pcs7: proc_parse: forbid dumping NFS remote locks
 - pcs7: files-reg: remove "unreachable" protobuf field as redundant
 - pcs7: files-reg: create spfs file in case of parent mount is SPFS
 - pcs7: files-reg: do not create spfs file in case of external resource
 - pcs7: spfs: remove "ns_list" option from "replace" command as obsolete
 - pcs7: namespace: mark mount namespaces as populated after the forking stage (#PSBM-48222)
 - pcs7: arch, x86 -- Add support for vz7 specific cpuid masking (#PSBM-47748 #PSBM-49423)
 - pcs7: scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - pcs7: scripts: restart all systemd automount services (#PSBM-46672)
 - pcs7: sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - pcs7: util: Add cr_set_root/cr_restore_root helpers
 - pcs7: spfs: do not treat existent file as error in create_reg_file
 - pcs7: seize: Take --timeout option into account when freezing processes (#PSBM-47539 #PSBM-47538)
 - pcs7: scripts: spfs-release-replace.sh introduced
 - pcs7: criu: spfs -- Fixup various nits for NFS sake
 - pcs7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - pcs7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - pcs7: mount: add support for NFSv4
 - pcs7: protobuf/mnt.proto: NFSv4 type added
 - pcs7: mount: add support for NFS
 - pcs7: protobuf/mnt.proto: NFS type added
 - pcs7: mount: add support for SUNRPC Pipefs
 - pcs7: protobuf/mnt.proto: RPC Pipefs type added
 - pcs7: scripts: allow-nfs-ports.sh added
 - pcs7: action-scripts: ACT_POST_NET_LOCK stage added
 - pcs7: scripts: spfs-change-mode.sh added
 - pcs7: action scripts: set spfs environment in run_scripts
 - pcs7: regular files: create temporary spfs file if marked as unreachable
 - pcs7: spfs: delayed mounts facility introduced
 - pcs7: cr-restore: declare SPFS_MNGR_SK service fd
 - pcs7: regular files: protobuf "unreachable" field introduced
 - pcs7: filemap: collect mapped file fs type
 - pcs7: reg_file_entry: add "mode" variable
 - pcs7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - pcs7: Wait aio pending requests (#PSBM-42488)
 - pcs7: criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - pcs7: Initial sync with vanilla v2.4

* Thu Jul 28 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.5
 - log: Print version into the log (#PSBM-50239)
 - files-reg: fix silly-renamed files migration
 - files-reg: improve spfs_file helper
 - mounts: export is_root_mount helper

* Tue Jul 26 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.4
 - Revert "sk-unix: forbid to dump NFS unix sockets" (#PSBM-47017)

* Tue Jul 26 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.3
 - mount: sysfs -- Use slave mounting for the root (#PSBM-50010)
 - util-vdso: correct vdso symbol's length

* Wed Jul 20 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.2
 - Makefile: install spfs-release-replace.sh script (#PSBM-49726)

* Mon Jul 18 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.1
 - files: Allow to dump ploopX files opened (#PSBM-49723)
 - version: Adjust numbering
 - Revert "files_reg: carry rdev with regular files"

* Tue Jul 12 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.49
 - seize: Wait the freezer to complete before processing tags (#PSBM-49439)
 - spfs: remove obsolete code
 - files-reg: migrate "spfs" files as ghost-ones
 - files-reg: conditionally dump content in dump_ghost_file
 - util: mkdirname helper introduced
 - files-reg: split create_ghost
 - files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - dump: Move task_comm_info helpers into seize.c

* Thu Jul 07 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.48
 - pcs7: arch, x86 -- Fix typo in cpuid masking code (#PSBM-49423)
 - spfs: do not tolerate file existence on creation

* Wed Jul 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.47
 - dump: Show task comm early
 - spfs: add device files creation support (#PSBM-48985)
 - files_reg: carry rdev with regular files

* Wed Jul 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.46
 - spfs: fix freeze cgroup path discovery
 - cgroup: new_cg_root_get helper introduced
 - criu: remove NFS unlinked files restriction
 - files-reg: migrate spfs unlinked file as "link remap" objects
 - files-reg: migrate spfs file as "link remap" objects
 - spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - spfs: explicitly pass size and mode to spfs_create_file
 - link_remap: do not create excessive links for a single file
 - cr-dump: discover fs type in fill_fd_params_special
 - proc_parse: fix vma file open mode recognition (#PSBM-49199)
 - Set hash for -u1 branch

* Mon Jun 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.45
 - tty: Don't forget to add eol when inverting slave pts paths (#PSBM-49008)

* Wed Jun 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.44
 - tty: Fix typos in vt driver choosing (#PSBM-48614)

* Wed Jun 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.43
 - mount: don't do MS_REC|MS_PRIVATE for host mounts (#PSBM-46298)
 - log: files-ext -- Show exactly which file can't be dumped
 - criu: util -- Add __read_fd_link helper

* Mon Jun 20 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.42
 - mount: forbid dumping overmounted NFS (#PSBM-48620)

* Sat Jun 18 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.41
 - zdtm: add a new test to check netlink sockets with queued data
 - netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - netlink: request flags for netlink sockets
 - sk-queue: add an ability to dump addresses for messages
 - check: check whether NETLINK_REPAIR is supported or not
 - unix: Do not autobind unnamed unix sockets (#PSBM-48446)
 - pcs7: images: Sync format with vanilla criu (#PSBM-48283)
 - sk-unix: forbid to dump NFS unix sockets
 - files-reg: forbid to dump unlinked NFS files
 - proc_parse: forbid dumping NFS remote locks
 - files-reg: remove "unreachable" protobuf field as redundant
 - files-reg: create spfs file in case of parent mount is SPFS
 - files-reg: do not create spfs file in case of external resource

* Wed Jun 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.40
 - spfs: remove "ns_list" option from "replace" command as obsolete

* Tue Jun 14 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.39
 - rpc: Implement @timeout interface (#PSBM-48256)

* Sat Jun 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.38
 - namespace: mark mount namespaces as populated after the forking stage (#PSBM-48222)

* Sat Jun 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.37
 - rpc: Add interface --freeze-cgroup option (#PSBM-44613)
 - pcs7: arch, x86 -- Add support for vz7 specific cpuid masking (#PSBM-47748)
 - dump: Allocate root_item before run pre-dump scripts (#PSBM-47737)
 - scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)

* Wed Jun 08 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.36
 - net/sysctl: fix ipv4 forwarding (#PSBM-47355)
 - scripts: terminate systemd-autofs-restart.sh if saved mountpoint is missing (#PSBM-44207)
 - scripts: return non zero if save_mountpoint() fails (#PSBM-44207)
 - scripts: remove bogus command substitution in systemd-autofs-restart.sh (#PSBM-44207)
 - scripts: detect EOF on read in a usual way in systemd-autofs-restart.sh (#PSBM-44207)

* Mon Jun 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.35
 - mount: don't add a separate entry for each enabled file systems (#PSBM-47221)

* Mon Jun 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.34
 - scripts: restart all systemd automount services (#PSBM-46672)

* Sat Jun 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.33
 - sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - util: Add cr_set_root/cr_restore_root helpers

* Thu Jun 02 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.32
 - zdtm/ptrace_sig: don't print from signal handlers (#PSBM-47772)
 - test: file_locks01 -- Test for dev change if only env is set (#PSBM-47714)
 - test: fanotify00 -- Test for device change if only env set
 - test: static, fanotify00 -- Don't compare @s_dev in test (#PSBM-47667)

* Fri May 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.31
 - spfs: do not treat existent file as error in create_reg_file
 - seize: Take --timeout option into account when freezing processes (#PSBM-47539 #PSBM-47538)
 - mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - build: Don't forget to relink arch builtins on change
 - scripts: spfs-release-replace.sh introduced
 - Revert "scripts: spfs-release-replace.sh introduced"
 - scripts: spfs-release-replace.sh introduced
 - scripts: call readlink in CT context in systemd-autofs-restart.sh
 - scripts: single style for command substitution in systemd-autofs-restart.sh (#PSBM-44207)
 - tty: Don't forget to unblock tty peers
 - tty: Save @flags unconditionaly for consistency
 - zdtm: check in-flight data in ttys
 - tty: Write unread pty buffers on post dump stage (#PSBM-41399)

* Tue May 24 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.30
 - criu: don't interrupt do_new_mount() after appling mount options (#PSBM-47489)

* Tue May 24 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.29
 - aio: Consider AIO pages as "should be dumped" (#PSBM-47489)
 - test/sockets: add test for shut down stream unix sockets (#PSBM-47023)
 - sk-unix: ignore shutdown mismatch in unix sockets
 - scripts: fix strings comparison in systemd-autofs-restart.sh

* Tue May 24 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.28
 - net/sysctl: zero-init stable_secret strings (#PSBM-30942)
 - net/sysctl: remove excess type conversions for sysctl_entry.type
 - net/sysctl: silence read error in case of CTL_FLAGS_READ_EIO_SKIP
 - zdtm/net/ipv6: add test for string stable_secret
 - sysctl: fix allocation for array of pointers
 - zdtm/net/ipv6: add test for confs
 - zdtm/net/ipv6: add devconfs6 and rand_range6
 - zdtm/net/ipv6: allow inacurate match for mldvX_unsolicited_report_interval
 - zdtm/net/ipv4: split save_and_set and check_and_restore
 - zdtm/net/ipv4: replace rand limits with rand ranges
 - zdtm/net/ipv4: make save_and_set and check_and_restore reusable
 - restore/net/ipv6: net device and def/all configuration
 - dump/net/ipv6: net device and def/all configuration
 - net/ipv6: add devconfs6 array to store config option's names
 - net/ipv6/protobuf: add device config options for ipv6
 - net/ipv4: add net_conf_op to reuse for ipv6
 - protobuf: add SysctlEntry for ipv4/ipv6 sysctl confs or some others
 - sysctl: add CTL_FLAGS_HAS to mark successful sysctl_op request
 - zdtm/net/ipv4: rename devconfs4 and rand_limit4 and dir4
 - net/ipv4: suffix devconfs with "4"
 - net/ipv4: add new sysctls
 - pcs7: criu: spfs -- Fixup various nits for NFS sake

* Wed May 18 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.27
 - pcs7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - pcs7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - pcs7: mount: add support for NFSv4
 - pcs7: protobuf/mnt.proto: NFSv4 type added
 - pcs7: mount: add support for NFS
 - pcs7: protobuf/mnt.proto: NFS type added
 - pcs7: mount: add support for SUNRPC Pipefs
 - pcs7: protobuf/mnt.proto: RPC Pipefs type added
 - pcs7: scripts: allow-nfs-ports.sh added
 - pcs7: action-scripts: ACT_POST_NET_LOCK stage added
 - pcs7: scripts: spfs-change-mode.sh added
 - pcs7: action scripts: set spfs environment in run_scripts
 - pcs7: regular files: create temporary spfs file if marked as unreachable
 - pcs7: spfs: delayed mounts facility introduced
 - pcs7: cr-restore: declare SPFS_MNGR_SK service fd
 - pcs7: regular files: protobuf "unreachable" field introduced
 - pcs7: filemap: collect mapped file fs type
 - pcs7: reg_file_entry: add "mode" variable
 - Add requirement for spfs package

* Wed May 18 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.26
 - pcs7: cgroup: Fix early update of @dir_name in rewrite_cgsets (#PSBM-46987)
 - plugins: Initialize plugins control by default

* Tue May 17 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.25
 - pcs7: mount: add support for external block devices (#PSBM-39381)

* Fri May 13 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.24
 - pcs7: aio: Fix mmap retval analysing

* Wed May 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.23
 - pcs7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - pcs7: Wait aio pending requests (#PSBM-42488)

* Wed May 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.22
 - mount: create a clean mount only if a sub directory is bind-mounted (#PSBM-46908)
 - mount: dump a file system only if a mount point isn't overmounted (#PSBM-46908)
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46908)
 - Revert "mount: dump a file system only if a mount point isn't overmounted"
 - Revert "mount: don't overmount a mount if it should be bind-mounted
somewhere"

* Tue May 10 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.21
 - scripts: fix mountinfo parsing in systemd-autofs-restart.sh (#PSBM-46889)

* Fri May 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.20
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46732 #PSBM-46662)
 - mount: remove an extra condition from mounts_equal()
 - mount: handle a case when parent and child mounts in the same directory
 - mount: dump a file system only if a mount point isn't overmounted
 - Revert "mount: don't overmount a mount if it should be bind-mounted
somewhere" (#PSBM-46732)
 - autofs: support of "hidden" catatonic mounts (#PSBM-46572)
 - autofs: rework pipe search logic a bit
 - build: Add ability to generate gprof output

* Thu May 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.19
 - autofs: support of "hidden" catatonic mounts (#PSBM-46572)
 - autofs: rework pipe search logic a bit
 - build: Add ability to generate gprof output

* Wed May 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.18
 - pcs7: scripts -- Make sure -1 pid is not passed (#PSBM-46572)

* Wed May 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.17
 - pcs7: Increase the number of files limit (#PSBM-46761)

* Mon May 02 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.16
 - scripts: do not use stat to discover fs type in systemd-autofs-restart.sh (#PSBM-46756)

* Fri Apr 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.15
 - scripts: save and restore target mount for autofs service (#PSBM-46672)

* Fri Apr 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.14
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46662)

* Thu Apr 28 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.13
 - pcs7: Dump only known controllers (#PSBM-46382)
 - Revert "cg: Add ability to dump predefined controllers only"

* Wed Apr 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.12
 - Revert "pcs7: Increase the number of files limit"
 - criu: dump filemap as soon as possible (#PSBM-46355)

* Wed Apr 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.11
 - autofs: collect new pipe fd as used (#PSBM-46601)

* Wed Apr 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.10
 - autofs: do not create dentries for indirect mount on bind-mounts (#PSBM-46572)

* Sat Apr 23 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.9
 - pcs7: Increase the number of files limit (#PSBM-46355)
 - build: install -- Don't forget to init DESTDIR
 - scripts: fix typo in binary path in systemd-autofs-restart.sh
 - restore: Wait for userns being prepared before moving into cgroups (v3)
 - Revert "restore: Wait for userns being prepared before moving into cgroups
(v2)"
 - cg: Add ability to dump predefined controllers only (#PSBM-46382)

* Thu Apr 21 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.8
 - scripts: join pid namespace in systemd-autofs-restart.sh (#PSBM-46470)
 - files: try to change fsuid only if linkat() failed (#PSBM-46201)
 - criu: tty -- Restore tty params synchronously (#PSBM-46382)

* Thu Apr 21 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.7
 - restore: Wait for userns being prepared before moving into cgroups (v2) (#PSBM-46360)
 - Revert "restore: Wait for userns being prepared before moving into cgroups"

* Wed Apr 20 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.6
 - autofs: use temporary value for virtual pgrp on dump
 - restore: Wait for userns being prepared before moving into cgroups (#PSBM-46360)

* Tue Apr 19 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.5
 - files: Correctly handle tasks with no open file descriptors (#PSBM-46269)

* Fri Apr 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.4
 - autofs: install -- Fix libexec prefix (#PSBM-46249)
 - autofs: install -- Ship scripts/systemd-autofs-restart.sh (#PSBM-46249)

* Fri Apr 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.3
 - autofs: install -- Ship scripts/systemd-autofs-restart.sh (#PSBM-46249)
 - autofs: install -- Ship {_libexecdir}

* Thu Apr 14 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.1
 - pcs7: Update Makefile.local
 - criu: action-scripts -- Don't access @root_item_pid if not present
 - zdtm: check the mem_dirty_track if --pre or --snap is set (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - ppc64le: fix build with UFFD (Pavel Emelyanov <xemul@virtuozzo.com>)
 - Fix compilation of action-scripts.c (Pavel Emelyanov <xemul@virtuozzo.com>)
 - kdat: Remove tcp_max_rshare (Pavel Emelyanov <xemul@virtuozzo.com>)
 - tcp: Send as much as possible (Pavel Emelyanov <xemul@virtuozzo.com>)
 - join-ns: Fix join-ns zdtm test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - sk: handle erorors of lseek (Pavel Emelyanov <xemul@virtuozzo.com>)
 - util: don't leak a socket (Pavel Emelyanov <xemul@virtuozzo.com>)
 - namespaces: don't leak memory on error paths (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: set NS_PID environment variable before "post-resume" hook (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - scripts: systemd-autofs-restart.sh added (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - build: Add export of sublevels and extra (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - build: compel -- Drop double targeting (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: "post-resume" hook introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - criu: opts -- Shuffle init_opts order (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: Drop config.h from deps (Pavel Emelyanov <xemul@virtuozzo.com>)
 - ns: Options join-ns and unshare are conflicting (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - compel: Initial commit for standalone tool (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - compel: piegen -- Introduce actions (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: piegen -- Add @arch option (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: piegen -- Add @uapi-dir option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - join-ns: add join-ns zdtm test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - join-ns: perform join_namespace according to join-ns opts (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - join-ns: add join-ns option to criu CLI and RPC (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd: add handling of zero pages (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: introduce uffd_handle_page (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: increment uffd_copied_pages only in one place (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: move the code out of the 'main' function (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: make some variable static global (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: move code into subfunctions (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd.c: remove unused variable vma_size (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked opts in autofs_mount (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked info in autofs_mount on error path (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked AutofsEntry in autofs_dump_entry (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: do not close NULL image (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: remove handling of VDSO pages (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: do not treat VDSO pages as lazy (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: Fix pr_debug format for vma start (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: fix device id modifier on error path in autofs_mnt_open (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - autofs: fix device id printf modifier on error path in autofs_mnt_open (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - autofs: do not treat old kernel as error in autofs_parse() (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: include limit.h before auto_fs.h (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: fix build on Fedora 22 (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd.c: do not call unneeded functions (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: move add_ns_shared_cb declaration to include/namespaces.h (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - Fix userfaultfd code with newer compilers (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - check: "autofs" feature added (Pavel Emelyanov <xemul@virtuozzo.com>)
 - zdtm.py: create "dev/autofs" root contruction (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: add autofs test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - mount: create target directory for AutoFS indirect mounts. (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: restore stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - autofs: declare ioctl helpers and constants (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pipes: export collect_one_pipe_ops() helper (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - files: new dup_fdinfo() and dup_fle() helpers introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - files: new "used" files list introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: dump fsinfo stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - autofs: parse fsinfo stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - protobuf: autofs entry introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - devices: add support for /dev/autofs (Pavel Emelyanov <xemul@virtuozzo.com>)
 - protobuf/mnt.proto: AutoFS type added (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Check private remount error code (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - unshare: Define UNSHARE_MOUNT_PROC constant (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: try to find a free pid between busy pids (v2) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: use rbtree to find a specified pid (v3) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: prepare to store all pid-s in rb-tree (v3) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: split alloc_pstree_helper (Pavel Emelyanov <xemul@virtuozzo.com>)
 - pstree: move state from pstree_item to pid (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Try to include userfaultfd with criu (part 2) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Try to include userfaultfd with criu (part 1) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Remove static from prepare_task_entries function (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Make skip_pages function available criu-wide (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - unshare: Support pidns (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Mount new proc (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Support mntns (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Preparations and CLI option (Pavel Emelyanov <xemul@virtuozzo.com>)
 - pcs7: Extend version output via local build (#PSBM-45009)
 - build: criu -- Don't forget to cleanup arch directory
 - cg: Add rollback in get_cg_set (#PSBM-45553)
 - cg: Add rollback for add_cgroup (#PSBM-45553)
 - cg: Fix use-after-free in put_ctls (#PSBM-45553)
 - pie: open_detach_mount -- Use pr_perror for regular build
 - util: return aligned pointers from shmalloc()
 - Makefile: drop 'rebuild' from help message
 - nmk: build.mk -- Add @libso-y helper
 - nmk: build.mk -- Add @hostprogs-y mode
 - nmk: msg.mk -- Add host- messages
 - nmk: build.mk -- Shrink gen-cc-rules
 - nmk: build.mk -- Drop any-match rule
 - nmk: build.mk -- Fix deps for target mode
 - nmk: build.mk -- Squash gen-rule-x into gen-cc-rules
 - nmk: Drop rules.mk
 - nmk: rules.mk -- Fix AFLAGS typo
 - tests: remap_dead_pid[_root] -- Run in namespace only
 - log: add gnu-styled output to stdout
 - build: images -- Add missing cleanups
 - namespaces: zero struct ns_id when allocating
 - criu: use strsignal to describe kill reason
 - nmk: build.mk -- Fix ar rule for external libs
 - nmk: build.mk -- Make process depend on Makefile itself
 - nmk: build.mk -- On cleanup use cleanup-y only
 - nmk: utils.mk -- Add cleanify helper
 - nmk: utils.mk -- Drop redundant spaces
 - nmk: build.mk -- Fix typo in gen-ar-target-rule
 - nmk: rules.mk -- Add per-obj flags
 - nmk: build.mk -- Drop unused objlist target
 - nmk: rules.mk -- Drop @CFLAGS_ and @ASFLAGS_ but add ability to bring them
via param
 - build: add mrproper target
 - build/nmk: add mrproper-y
 - build: Drop @images
 - nmk: scritps/macro.mk -- Enhance gen-built-in
 - x86/restorer: drop unused struct pt_regs
 - types: Remove setns override with sys_setns
 - rst-malloc: adjust free_bytes in rst_mem_align_cpos
 - netfilter: add -n to iptables and ip6tables calls
 - build: docs -- Use autogenerated footer
 - pstree: try to find a free pid between busy pids (v2)
 - pstree: use rbtree to find a specified pid (v3)
 - pstree: prepare to store all pid-s in rb-tree (v3)
 - pstree: split alloc_pstree_helper
 - pstree: move state from pstree_item to pid
 - criu: seize -- Don't left dangling @processes_to_wait_pids pointer
 - libnetlink: back port a fix for nlattr_parse()
 - netlink: Use nlattr instead of rtattr
 - criu: pstree_switch_state -- Fix nil deref on error path
 - irmap: use kdev everywere
 - dump: check for conflicts with the dead processes
 - irmap: don't try to dereference a null pointer
 - mounts: handle device numbers in different formats properly
 - criu: Use __NR_memfd_create for testing memfd presence
 - build: Conditionally defined SYS_* constants
 - build: criu -- Don't link with syscalls library
 - mount: don't use a shared mount to get a clean mount
 - mount: master_id should be 0 for new mounts
 - mount: restore a shared group for propagated mounts
 - build: clean up various other bits
 - build: Add verbose message on packages needed for CRIU building
 - build: Unify phony forms usage
 - pre-dump: don't waste time in error cases
 - dump: pre-dump should never kill processes
 - make: Improve tar generation
 - pcs7: Update local version
 - dump: don't call rollback actions from a signal handler (#PSBM-44371)
 - mounts: Skip already bound siblings in propagate_siblings()
 - PCS7: cgroup: Always restore predefined VE props (#PSBM-41406)
 - files-reg: Fix rm_parent_dirs() counter
 - files-reg: Delete ghost file numeric index
 - files-reg: Revert: Make try_clean_ghost() use struct ghost_file ptr
 - zdtm: Disable unlink_regular00 by default
 - zdtm: Add unlink_regular00 test
 - files-reg: Recreate deleted parent directories during restore of ghost file
 - files-reg: Create ghost files in first existing parent directory
 - files-reg: Move applying ghost file metadata from create_ghost() to separate
function
 - files-reg: Make try_clean_ghost() use struct ghost_file ptr
 - files-reg: Refactor create_ghost()
 - seize: detach from external processes before killing dumped processes (v2) (#PSBM-43795)
 - mount: separate private remount conditions for external and non-external (#PSBM-42829)
 - plugin: Add PRE_DUMP stage into plugins
 - dump: save master_id for the root mount (#PSBM-43260)
 - crtools: describe the inherit-fd option
 - parasite: Don't left memfd opened inside dumpee (#PSBM-43199)
 - scripts: post-setup-namespaces
 - seize: remove extra \n from the error message (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: don't detach from a task if a freezer cgroup is set (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: detach from all processes before waiting the root task (Cyrill
Gorcunov <gorcunov@openvz.org>) (#PSBM-43089)
 - make: Add Makefile.version (Cyrill Gorcunov <gorcunov@openvz.org>)

* Wed Apr 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.8
 - pcs7: Extend version output via local build (#PSBM-45009)

* Tue Apr 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.7
 - build: criu -- Don't forget to cleanup arch directory
 - cg: Add rollback in get_cg_set (#PSBM-45553)
 - cg: Add rollback for add_cgroup (#PSBM-45553)
 - cg: Fix use-after-free in put_ctls (#PSBM-45553)
 - pie: open_detach_mount -- Use pr_perror for regular build
 - util: return aligned pointers from shmalloc()
 - Makefile: drop 'rebuild' from help message
 - nmk: build.mk -- Add @libso-y helper
 - nmk: build.mk -- Add @hostprogs-y mode
 - nmk: msg.mk -- Add host- messages
 - nmk: build.mk -- Shrink gen-cc-rules
 - nmk: build.mk -- Drop any-match rule
 - nmk: build.mk -- Fix deps for target mode
 - nmk: build.mk -- Squash gen-rule-x into gen-cc-rules
 - nmk: Drop rules.mk
 - nmk: rules.mk -- Fix AFLAGS typo
 - tests: remap_dead_pid[_root] -- Run in namespace only
 - log: add gnu-styled output to stdout
 - build: images -- Add missing cleanups
 - namespaces: zero struct ns_id when allocating
 - criu: use strsignal to describe kill reason
 - nmk: build.mk -- Fix ar rule for external libs
 - nmk: build.mk -- Make process depend on Makefile itself
 - nmk: build.mk -- On cleanup use cleanup-y only
 - nmk: utils.mk -- Add cleanify helper
 - nmk: utils.mk -- Drop redundant spaces
 - nmk: build.mk -- Fix typo in gen-ar-target-rule
 - nmk: rules.mk -- Add per-obj flags
 - nmk: build.mk -- Drop unused objlist target
 - nmk: rules.mk -- Drop @CFLAGS_ and @ASFLAGS_ but add ability to bring them
via param
 - build: add mrproper target
 - build/nmk: add mrproper-y
 - build: Drop @images
 - nmk: scritps/macro.mk -- Enhance gen-built-in
 - x86/restorer: drop unused struct pt_regs
 - types: Remove setns override with sys_setns

* Fri Mar 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.6
 - rst-malloc: adjust free_bytes in rst_mem_align_cpos

* Wed Mar 23 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.5
 - netfilter: add -n to iptables and ip6tables calls
 - build: docs -- Use autogenerated footer
 - pstree: try to find a free pid between busy pids (v2)
 - pstree: use rbtree to find a specified pid (v3)
 - pstree: prepare to store all pid-s in rb-tree (v3)
 - pstree: split alloc_pstree_helper
 - pstree: move state from pstree_item to pid

* Thu Mar 17 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.4
 - criu: seize -- Don't left dangling @processes_to_wait_pids pointer

* Wed Mar 16 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.3
 - libnetlink: back port a fix for nlattr_parse()
 - netlink: Use nlattr instead of rtattr

* Wed Mar 16 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.2
 - criu: pstree_switch_state -- Fix nil deref on error path

* Tue Mar 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.1
 - irmap: use kdev everywere
 - dump: check for conflicts with the dead processes
 - irmap: don't try to dereference a null pointer
 - mounts: handle device numbers in different formats properly
 - criu: Use __NR_memfd_create for testing memfd presence
 - build: Conditionally defined SYS_* constants
 - build: criu -- Don't link with syscalls library
 - mount: don't use a shared mount to get a clean mount
 - mount: master_id should be 0 for new mounts
 - mount: restore a shared group for propagated mounts
 - build: clean up various other bits
 - build: Add verbose message on packages needed for CRIU building
 - build: Unify phony forms usage
 - pre-dump: don't waste time in error cases
 - dump: pre-dump should never kill processes
 - make: Improve tar generation
 - pcs7: Update local version
 - dump: don't call rollback actions from a signal handler (#PSBM-44371)
 - mounts: Skip already bound siblings in propagate_siblings()
 - PCS7: cgroup: Always restore predefined VE props (#PSBM-41406)
 - files-reg: Fix rm_parent_dirs() counter
 - files-reg: Delete ghost file numeric index
 - files-reg: Revert: Make try_clean_ghost() use struct ghost_file ptr
 - zdtm: Disable unlink_regular00 by default
 - zdtm: Add unlink_regular00 test
 - files-reg: Recreate deleted parent directories during restore of ghost file
 - files-reg: Create ghost files in first existing parent directory
 - files-reg: Move applying ghost file metadata from create_ghost() to separate
function
 - files-reg: Make try_clean_ghost() use struct ghost_file ptr
 - files-reg: Refactor create_ghost()
 - seize: detach from external processes before killing dumped processes (v2) (#PSBM-43795)
 - mount: separate private remount conditions for external and non-external (#PSBM-42829)
 - plugin: Add PRE_DUMP stage into plugins
 - dump: save master_id for the root mount (#PSBM-43260)
 - crtools: describe the inherit-fd option
 - parasite: Don't left memfd opened inside dumpee (#PSBM-43199)
 - scripts: post-setup-namespaces
 - seize: remove extra \n from the error message (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: don't detach from a task if a freezer cgroup is set (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: detach from all processes before waiting the root task (Cyrill
Gorcunov <gorcunov@openvz.org>) (#PSBM-43089)
 - make: Add Makefile.version (Cyrill Gorcunov <gorcunov@openvz.org>)
 - Add dep for libnl3-devel

* Tue Mar 01 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.15
 - dump: don't call rollback actions from a signal handler (#PSBM-44371)

* Wed Feb 17 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.14
 - mounts: Skip already bound siblings in propagate_siblings()

* Thu Feb 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.13
 - PCS7: cgroup: Always restore predefined VE props (#PSBM-41406)

* Wed Feb 10 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.12
 - files-reg: Fix rm_parent_dirs() counter
 - files-reg: Delete ghost file numeric index
 - files-reg: Revert: Make try_clean_ghost() use struct ghost_file ptr
 - zdtm: Disable unlink_regular00 by default
 - zdtm: Add unlink_regular00 test
 - files-reg: Recreate deleted parent directories during restore of ghost file
 - files-reg: Create ghost files in first existing parent directory
 - files-reg: Move applying ghost file metadata from create_ghost() to separate
function
 - files-reg: Make try_clean_ghost() use struct ghost_file ptr
 - files-reg: Refactor create_ghost()

* Tue Feb 09 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.11
 - seize: detach from external processes before killing dumped processes (v2) (#PSBM-43795)

* Thu Feb 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.10
 - mount: separate private remount conditions for external and non-external (#PSBM-42829)

* Thu Feb 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.9
 - plugin: Add PRE_DUMP stage into plugins

* Fri Jan 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.8
 - dump: save master_id for the root mount (#PSBM-43260)
 - crtools: describe the inherit-fd option
 - parasite: Don't left memfd opened inside dumpee (#PSBM-43199)

* Wed Jan 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.7
 - gitignore: ignore some more generated testcases (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - seize: remove extra \n from the error message (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - seize: don't detach from a task if a freezer cgroup is set (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - seize: detach from all processes before waiting the root task (Pavel
Emelyanov <xemul@virtuozzo.com>) (#PSBM-43089)
 - zdtm: Add suid flag to binfmt_misc test (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - ns: Remove __rst_new_ns_id (Pavel Emelyanov <xemul@virtuozzo.com>)
 - fds: Remove unused arg from close_old_fds() (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tmpfs: don't try to dump mountpoint at 0 fd (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - criu [PATCH] post-setup-namespaces (Pavel Emelyanov <xemul@virtuozzo.com>)
 - service: add support for the --external option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - dump: add some stray newlines to pr_infos (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - binfmt_misc: Make debug printed using pr_debug() (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: Add binfmt_misc test (Pavel Emelyanov <xemul@virtuozzo.com>)

* Tue Jan 19 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.6
 - scripts: post-setup-namespaces
 - seize: remove extra \n from the error message (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: don't detach from a task if a freezer cgroup is set (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: detach from all processes before waiting the root task (Cyrill
Gorcunov <gorcunov@openvz.org>) (#PSBM-43089)
 - make: Add Makefile.version (Cyrill Gorcunov <gorcunov@openvz.org>)
 - ppc64: introduce CPU feature checking operations (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm/test: Fix live/static/netns-nf dependency (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm.py: Add optional dependency support (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - mem: Handle the case when kernel doesn't support dirty track reset (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - kdat: Handle pagemaps with zeroed pfns (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: Use /usr/bin/diff instead of /bin/diff (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - remap: fix dead pid remap of /proc/<pid> (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/session00: close a signal pipe in all processes (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - fix compilation after previous commit (Pavel Emelyanov <xemul@virtuozzo.com>)
 - util: Optimize vaddr_to_pfn (Pavel Emelyanov <xemul@virtuozzo.com>)
 - zdtm/chroot: wait when a child closes a descriptor (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - make: update target to measure code coverage (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm/session00: wait when a child closes fd (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: Correct syscall numbers for fanotify00 testcase (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - define macro for stack alignment (Pavel Emelyanov <xemul@virtuozzo.com>)
 - tty: use PRIx64 to print dev_t (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Force per-test logs if report is requested (Pavel Emelyanov
<xemul@parallels.com>)
 - arch: define the readlinkat syscall for all architectures (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Align stack pointer for arm64 (Pavel Emelyanov <xemul@parallels.com>)
 - restorer: Update RESTORE_ALIGN_STACK for arm64 (Pavel Emelyanov
<xemul@parallels.com>)
 - restore: Align stack to 16 bytes for arm64 (Pavel Emelyanov
<xemul@parallels.com>)
 - arm: Fix wrong system call number (Pavel Emelyanov <xemul@parallels.com>)
 - criu-log: introduce print_once (Pavel Emelyanov <xemul@parallels.com>)
 - kerndat: do not report errors on feature test (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: write an inventory image after dumping all processes (Pavel Emelyanov
<xemul@parallels.com>)
 - test: add a new test to check external terminals (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: add a new test to check inherited tty-s (Pavel Emelyanov
<xemul@parallels.com>)
 - tty: allow to dump and restore external terminals (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - crtools: add ability to set list of external resources (Pavel Emelyanov
<xemul@parallels.com>)
 - tty: use a pair of dev and rdev to identify a terminal (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: add a script to check inherit file descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - mnt: Allow for external mounts to be fsroot ones (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: unfreeze test processes before killing them (Pavel Emelyanov
<xemul@parallels.com>)
 - syscall: use a correct type for timer_t (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: Fix spelling error in a error message (Pavel Emelyanov
<xemul@parallels.com>)
 - arm: proc_parse -- Fix u64 format warnings (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: change the root master_id on restore only (Pavel Emelyanov
<xemul@parallels.com>)
 - cr-check: add logiuid feature (Pavel Emelyanov <xemul@parallels.com>)
 - criu: fetch kdat.has_loginuid value on C/R (Pavel Emelyanov
<xemul@parallels.com>)
 - kerndat: add has_loginuid to kerndat_s (Pavel Emelyanov
<xemul@parallels.com>)
 - creds: restore -- Honor rst_mem_alloc rules (Pavel Emelyanov
<xemul@parallels.com>)
 - tcp: Try harder to restore recv queue (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: When no logs, do not add them to report (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Mark nouser tests as such (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: Add user mode job (Pavel Emelyanov <xemul@parallels.com>)
 - proc: Fix aio mapping detection (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Check how user-mode works (Pavel Emelyanov <xemul@parallels.com>)
 - parasite: Load code blobs via memfd (Pavel Emelyanov <xemul@parallels.com>)
 - proc: Use smaps path for file (Pavel Emelyanov <xemul@parallels.com>)
 - pagemap-cache: Use greedy mode if pagemap inaccessible (Pavel Emelyanov
<xemul@parallels.com>)
 - vdso: Don't fail if pagemap is not accessbile (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: Dont read prohibited kernel files (Pavel Emelyanov
<xemul@parallels.com>)
 - kerndat: Read anon shmem dev via maps (Pavel Emelyanov <xemul@parallels.com>)
 - util: Ability to ignore errno when opening proc (Pavel Emelyanov
<xemul@parallels.com>)
 - parasite: Add @pad argument for syscall run (Pavel Emelyanov
<xemul@parallels.com>)
 - proc: Get full file path into handle_vma (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: Remove security (Pavel Emelyanov <xemul@parallels.com>)
 - test: different_creds -- Enhance the testing (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Add ARRAY_SIZE into the header (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: set the dumpable flag after setuid (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't worry if a test class doesn't have ns() and static() (Pavel
Emelyanov <xemul@parallels.com>)
 - test/inhfd: use os.fdopen instead of a home-made class (Pavel Emelyanov
<xemul@parallels.com>)
 - cpt/rst: access and modification time of ghost files (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41401)
 - creds: dump -- Implement per-thread dump of credentials (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - creds: restore -- Implement per-thread restore of credentials (Pavel
Emelyanov <xemul@parallels.com>)
 - creds: Move proc_status_creds::cap_X at the end of structure (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - creds: Allocate CredsEntry for every thread in core_entry_alloc (Pavel
Emelyanov <xemul@parallels.com>)
 - creds: protobuf -- Move @creds_entry into @thread_core_entry (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - xmalloc: Add xmemdup helper (Pavel Emelyanov <xemul@parallels.com>)
 - arm: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - ppc64: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - x86: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - Fix 'mnt_path' may be used uninitialized in this function (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm_ct: Mount binfmt misc in ct creation (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Mount binfmt misc in run_ct (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: build criu with debuginfo (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm/file_locks04: use test_waitsig() to synchronize child and parent (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm/fifo_wronly: wait when a child opens a file descriptor (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: remove warnings about existent directories (Pavel Emelyanov
<xemul@parallels.com>)
 - binfmt_misc: Skip dumping if it's not virtual (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Test how freeze cgroup works (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/pstree: check return codes (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm/pstree: read from a correct file descriptor (Pavel Emelyanov
<xemul@parallels.com>)
 - test: wait when a prepartion stage will be completed (Pavel Emelyanov
<xemul@parallels.com>)
 - pipe00: when while a child is preparing file descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/socket_close_data01: wait a child before c/r (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/sigpending: wait a child before C/R (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: don't hardcode file names in test soruces (Pavel Emelyanov
<xemul@parallels.com>)
 - test: write_read10 -- Wait for children to create (Pavel Emelyanov
<xemul@parallels.com>)
 - test: write_read_10 -- Fix typo in testing opened file descriptor (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm:mntns_open: wait when a child process opens descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/mountpoints: wait when a child process opens descriptors (Pavel
Emelyanov <xemul@parallels.com>)
 - files-reg: fix compilation issues (Pavel Emelyanov <xemul@parallels.com>)
 - mountpoints: don't re-create /dev/null (Pavel Emelyanov
<xemul@parallels.com>)
 - rst: set mode on ghost-files after write (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41401)
 - dump: add timeout for collecting processes (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: factor out cleanup code into separate functions (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: fix return code in message on pre-dump failure (Pavel Emelyanov
<xemul@parallels.com>)
 - seize: slightly cleanup collect_pstree() exit path. (Pavel Emelyanov
<xemul@parallels.com>)
 - cr-restore: optimize {loginuid,oom_score_adj} restoring (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: use xsprintf() in resolve_external_mounts() (Pavel Emelyanov
<xemul@parallels.com>)
 - sysfs_parse: use xsprintf() in fixup_aufs_vma_fd() (Pavel Emelyanov
<xemul@parallels.com>)
 - irmap: use xsprintf() in irmap_update_dir() (Pavel Emelyanov
<xemul@parallels.com>)
 - cgroup: use xsprintf() in rewrite_cgsets() (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: use xstrcat() in attach_option() (Pavel Emelyanov
<xemul@parallels.com>)
 - util: new string helpers introduced (Pavel Emelyanov <xemul@parallels.com>)
 - test: block prctl in seccomp_filter (Pavel Emelyanov <xemul@parallels.com>)
 - pie: move seccomp before creds to avoid resoring them after setuid (Pavel
Emelyanov <xemul@parallels.com>)
 - test: setuid in seccomp_filter test to have it fail (Pavel Emelyanov
<xemul@parallels.com>)
 - ptrace: start tracing processes before restoring creds (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: check shared mounts more carefully (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: do nothing if a root mount isn't slave (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: fix comparing files, maps and mounts (Pavel Emelyanov
<xemul@parallels.com>)
 - Fix compilation after previous commit (Pavel Emelyanov <xemul@parallels.com>)
 - files-reg: restore PR_SET_DUMPABLE flag after setfsuid (Pavel Emelyanov
<xemul@parallels.com>)
 - unix: Fix double restoring of peerless unix sockets, which are peers for
others (Pavel Emelyanov <xemul@parallels.com>)
 - loginuid: save value of loginuid from a target userns (Pavel Emelyanov
<xemul@parallels.com>)
 - lsm: don't leak apparmor string in the case of "unconfined" (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: tests should not inherite file descriptors from zdtm.py (Pavel
Emelyanov <xemul@parallels.com>)
 - seize: do not try to detach killed tasks (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Change oom_score_adj score value (Pavel Emelyanov
<xemul@parallels.com>)
 - files: check fd flags after restore (Pavel Emelyanov <xemul@parallels.com>)
 - restore: restore freezer cgroup state (Pavel Emelyanov <xemul@parallels.com>)
 - restore: split finalize_restore into two stages (Pavel Emelyanov
<xemul@parallels.com>)
 - cgroups: save freezer state during dump (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: The 'mems' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: The 'fds' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: The 'ps' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Explore action and stubs (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: bind-mount a test root as slave (Pavel Emelyanov
<xemul@parallels.com>)
 - makefile: use zdtm.py to execute tests (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: compare a set of mounts before and after c/r (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: fix a value of ZDTM_THREAD_BOMB (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't mix tab and spaces (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: collect fds and maps for all test processes (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't take into acount the root master_id (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't remount a slave mount as private when it isn't required (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm: add loginuid restore test (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: add test for oom_score_adj restore (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: unset loginuid value before creating userns (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - criu: restore loginuid & oom_score_adj values (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - criu: dump loginuid & oom_score_adj values (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - make: Fix @install-criu target (Pavel Emelyanov <xemul@parallels.com>)
 - test: report actual errno on seccomp prctl failure (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add action for cleaning nsroot (Pavel Emelyanov
<xemul@parallels.com>)
 - Rename cr_opts.ps_port into port (Pavel Emelyanov <xemul@parallels.com>)
 - Introduce the read_into_buffer helper (Pavel Emelyanov <xemul@parallels.com>)
 - seize: don't wory if a cgroup contains some extra tasks (v3) (Pavel Emelyanov
<xemul@parallels.com>)
 - fstype: "mount" callback introduced (Pavel Emelyanov <xemul@parallels.com>)
 - pstree: more pstree-related helpers (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: No parallelizm for group test (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add write perms for all bins in test (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Fix compilation after previous commit (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Add groups (Pavel Emelyanov <xemul@parallels.com>)
 - freebind: Use different ports (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Fix deps for group start (Pavel Emelyanov <xemul@parallels.com>)
 - criu: tty: pick only master as a control terminal (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-42093)
 - test: Add inotify02 into the Makefile (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Speed up jenkins test ~60 times (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Fix ipc load/dump for io.BytesIO input/output (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Add dump for semaphores (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add handling of msgqueue (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add dump method for shmem pages (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add payload handler for shmem pages (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Add payload handler for semaphore images (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add step-by-step execution (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Print out and strace file names (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Print test output on screen when possible (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: catch KeyError instead of ValueError for sets (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: fix a race between restoring namespaces and file mappings (v2) (Pavel
Emelyanov <xemul@parallels.com>)
 - mount: pick out a function to set ROOT_FD_OFF (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Fix casts for fixed and sfixed types (Pavel Emelyanov
<xemul@parallels.com>)
 - seize: get_freezer_state -- Relax stack (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: set a type argument for mknod (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't worry if uns isn't in run_flavs (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: stop doing anything if populate_mnt_ns() failed (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't worry if a binfmt_misc image is empty (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Fix CRIT test to skip non-criu images and provide cumulative output
(Pavel Emelyanov <xemul@parallels.com>)
 - mount: don't add dot to a path (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Pretty print vma flags and status (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: umount a temporary mount with MTN_DETACH (Pavel Emelyanov
<xemul@parallels.com>)
 - pagemap-cache: add const-qualifier to pmc's vma (Pavel Emelyanov
<xemul@parallels.com>)
 - page-xfer: fix wrong hole address offset (Pavel Emelyanov
<xemul@parallels.com>)
 - test: Add inotify02 (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Fix zdtm_test._env data type (Pavel Emelyanov <xemul@parallels.com>)
 - sysctl: don't skip erros (Pavel Emelyanov <xemul@parallels.com>)
 - sysctl: really skip missing entries in __nonuserns_sysctl_op() (Pavel
Emelyanov <xemul@parallels.com>)
 - criu: x86_32: change stack align to 16 bit on parasite head (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: add the mnt_id feature if a test uses more than one mntns (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm.py: skip the uns flavor if userns isn't suppported (Pavel Emelyanov
<xemul@parallels.com>)
 - lsm: add a --lsm-profile flag (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Encode back pretty IP addresses (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Show devices nicely (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: Add test for crit de/encode correctness (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Run tests in best flavor (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Count skipped tests (Pavel Emelyanov <xemul@parallels.com>)
 - mount: don't rewrite root for external mounts (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41932)
 - unix: Add support for restoring receive queue for unix DGRAM sockets (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm: add mntns_rw_ro_rw to the test list (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: fix restoring a bind-mount when its root is overmounted (Pavel
Emelyanov <xemul@parallels.com>)
 - mount: refactor do_bind_mount() (Pavel Emelyanov <xemul@parallels.com>)
 - mount: pick out a function to bind mount a point in a tmp place (Pavel
Emelyanov <xemul@parallels.com>)
 - mnt: Carry run-time device ID in mount_info (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41610)
 - zdtm.py: The groups_test class for running groups (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Generator of groups of tests (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Prepare zdtm_test and flavors for mass test start (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Remove unneeded re-exec (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Factor out ps showing code (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Introduce explicit prepare_namespaces() routine (Pavel Emelyanov
<xemul@parallels.com>)
 - fs: Add binfmt_misc support (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Add socket_close_data01 test (Pavel Emelyanov <xemul@parallels.com>)
 - Update source (Cyrill Gorcunov <gorcunov@gmail.com>)
 - Remove obsoleted patches (Dmitry Mishin <dim@virtuozzo.com>)

* Tue Dec 29 2015 Dmitry Mishin <dim@virtuozzo.com> 1.8.0.3
 - mnt: Allow for external mounts to be fsroot ones (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: unfreeze test processes before killing them (Pavel Emelyanov
<xemul@parallels.com>)
 - syscall: use a correct type for timer_t (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: Fix spelling error in a error message (Pavel Emelyanov
<xemul@parallels.com>)
 - arm: proc_parse -- Fix u64 format warnings (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: change the root master_id on restore only (Pavel Emelyanov
<xemul@parallels.com>)
 - cr-check: add logiuid feature (Pavel Emelyanov <xemul@parallels.com>)
 - criu: fetch kdat.has_loginuid value on C/R (Pavel Emelyanov
<xemul@parallels.com>)
 - kerndat: add has_loginuid to kerndat_s (Pavel Emelyanov
<xemul@parallels.com>)
 - creds: restore -- Honor rst_mem_alloc rules (Pavel Emelyanov
<xemul@parallels.com>)
 - tcp: Try harder to restore recv queue (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: When no logs, do not add them to report (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Mark nouser tests as such (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: Add user mode job (Pavel Emelyanov <xemul@parallels.com>)
 - proc: Fix aio mapping detection (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Check how user-mode works (Pavel Emelyanov <xemul@parallels.com>)
 - parasite: Load code blobs via memfd (Pavel Emelyanov <xemul@parallels.com>)
 - proc: Use smaps path for file (Pavel Emelyanov <xemul@parallels.com>)
 - pagemap-cache: Use greedy mode if pagemap inaccessible (Pavel Emelyanov
<xemul@parallels.com>)
 - vdso: Don't fail if pagemap is not accessbile (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: Dont read prohibited kernel files (Pavel Emelyanov
<xemul@parallels.com>)
 - kerndat: Read anon shmem dev via maps (Pavel Emelyanov <xemul@parallels.com>)
 - util: Ability to ignore errno when opening proc (Pavel Emelyanov
<xemul@parallels.com>)
 - parasite: Add @pad argument for syscall run (Pavel Emelyanov
<xemul@parallels.com>)
 - proc: Get full file path into handle_vma (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: Remove security (Pavel Emelyanov <xemul@parallels.com>)
 - test: different_creds -- Enhance the testing (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Add ARRAY_SIZE into the header (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: set the dumpable flag after setuid (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't worry if a test class doesn't have ns() and static() (Pavel
Emelyanov <xemul@parallels.com>)
 - test/inhfd: use os.fdopen instead of a home-made class (Pavel Emelyanov
<xemul@parallels.com>)
 - cpt/rst: access and modification time of ghost files (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41401)
 - creds: dump -- Implement per-thread dump of credentials (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - creds: restore -- Implement per-thread restore of credentials (Pavel
Emelyanov <xemul@parallels.com>)
 - creds: Move proc_status_creds::cap_X at the end of structure (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - creds: Allocate CredsEntry for every thread in core_entry_alloc (Pavel
Emelyanov <xemul@parallels.com>)
 - creds: protobuf -- Move @creds_entry into @thread_core_entry (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - xmalloc: Add xmemdup helper (Pavel Emelyanov <xemul@parallels.com>)
 - arm: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - ppc64: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - x86: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - Fix 'mnt_path' may be used uninitialized in this function (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm_ct: Mount binfmt misc in ct creation (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Mount binfmt misc in run_ct (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: build criu with debuginfo (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm/file_locks04: use test_waitsig() to synchronize child and parent (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm/fifo_wronly: wait when a child opens a file descriptor (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: remove warnings about existent directories (Pavel Emelyanov
<xemul@parallels.com>)
 - binfmt_misc: Skip dumping if it's not virtual (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Test how freeze cgroup works (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/pstree: check return codes (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm/pstree: read from a correct file descriptor (Pavel Emelyanov
<xemul@parallels.com>)
 - test: wait when a prepartion stage will be completed (Pavel Emelyanov
<xemul@parallels.com>)
 - pipe00: when while a child is preparing file descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/socket_close_data01: wait a child before c/r (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/sigpending: wait a child before C/R (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: don't hardcode file names in test soruces (Pavel Emelyanov
<xemul@parallels.com>)
 - test: write_read10 -- Wait for children to create (Pavel Emelyanov
<xemul@parallels.com>)
 - test: write_read_10 -- Fix typo in testing opened file descriptor (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm:mntns_open: wait when a child process opens descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/mountpoints: wait when a child process opens descriptors (Pavel
Emelyanov <xemul@parallels.com>)
 - files-reg: fix compilation issues (Pavel Emelyanov <xemul@parallels.com>)
 - mountpoints: don't re-create /dev/null (Pavel Emelyanov
<xemul@parallels.com>)
 - rst: set mode on ghost-files after write (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41401)
 - dump: add timeout for collecting processes (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: factor out cleanup code into separate functions (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: fix return code in message on pre-dump failure (Pavel Emelyanov
<xemul@parallels.com>)
 - seize: slightly cleanup collect_pstree() exit path. (Pavel Emelyanov
<xemul@parallels.com>)
 - cr-restore: optimize {loginuid,oom_score_adj} restoring (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: use xsprintf() in resolve_external_mounts() (Pavel Emelyanov
<xemul@parallels.com>)
 - sysfs_parse: use xsprintf() in fixup_aufs_vma_fd() (Pavel Emelyanov
<xemul@parallels.com>)
 - irmap: use xsprintf() in irmap_update_dir() (Pavel Emelyanov
<xemul@parallels.com>)
 - cgroup: use xsprintf() in rewrite_cgsets() (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: use xstrcat() in attach_option() (Pavel Emelyanov
<xemul@parallels.com>)
 - util: new string helpers introduced (Pavel Emelyanov <xemul@parallels.com>)
 - test: block prctl in seccomp_filter (Pavel Emelyanov <xemul@parallels.com>)
 - pie: move seccomp before creds to avoid resoring them after setuid (Pavel
Emelyanov <xemul@parallels.com>)
 - test: setuid in seccomp_filter test to have it fail (Pavel Emelyanov
<xemul@parallels.com>)
 - ptrace: start tracing processes before restoring creds (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: check shared mounts more carefully (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: do nothing if a root mount isn't slave (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: fix comparing files, maps and mounts (Pavel Emelyanov
<xemul@parallels.com>)
 - Fix compilation after previous commit (Pavel Emelyanov <xemul@parallels.com>)
 - files-reg: restore PR_SET_DUMPABLE flag after setfsuid (Pavel Emelyanov
<xemul@parallels.com>)
 - unix: Fix double restoring of peerless unix sockets, which are peers for
others (Pavel Emelyanov <xemul@parallels.com>)
 - loginuid: save value of loginuid from a target userns (Pavel Emelyanov
<xemul@parallels.com>)
 - lsm: don't leak apparmor string in the case of "unconfined" (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: tests should not inherite file descriptors from zdtm.py (Pavel
Emelyanov <xemul@parallels.com>)
 - seize: do not try to detach killed tasks (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Change oom_score_adj score value (Pavel Emelyanov
<xemul@parallels.com>)
 - files: check fd flags after restore (Pavel Emelyanov <xemul@parallels.com>)
 - restore: restore freezer cgroup state (Pavel Emelyanov <xemul@parallels.com>)
 - restore: split finalize_restore into two stages (Pavel Emelyanov
<xemul@parallels.com>)
 - cgroups: save freezer state during dump (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: The 'mems' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: The 'fds' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: The 'ps' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Explore action and stubs (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: bind-mount a test root as slave (Pavel Emelyanov
<xemul@parallels.com>)
 - makefile: use zdtm.py to execute tests (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: compare a set of mounts before and after c/r (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: fix a value of ZDTM_THREAD_BOMB (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't mix tab and spaces (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: collect fds and maps for all test processes (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't take into acount the root master_id (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't remount a slave mount as private when it isn't required (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm: add loginuid restore test (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: add test for oom_score_adj restore (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: unset loginuid value before creating userns (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - criu: restore loginuid & oom_score_adj values (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - criu: dump loginuid & oom_score_adj values (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - make: Fix @install-criu target (Pavel Emelyanov <xemul@parallels.com>)
 - test: report actual errno on seccomp prctl failure (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add action for cleaning nsroot (Pavel Emelyanov
<xemul@parallels.com>)
 - Rename cr_opts.ps_port into port (Pavel Emelyanov <xemul@parallels.com>)
 - Introduce the read_into_buffer helper (Pavel Emelyanov <xemul@parallels.com>)
 - seize: don't wory if a cgroup contains some extra tasks (v3) (Pavel Emelyanov
<xemul@parallels.com>)
 - fstype: "mount" callback introduced (Pavel Emelyanov <xemul@parallels.com>)
 - pstree: more pstree-related helpers (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: No parallelizm for group test (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add write perms for all bins in test (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Fix compilation after previous commit (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Add groups (Pavel Emelyanov <xemul@parallels.com>)
 - freebind: Use different ports (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Fix deps for group start (Pavel Emelyanov <xemul@parallels.com>)
 - criu: tty: pick only master as a control terminal (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-42093)
 - test: Add inotify02 into the Makefile (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Speed up jenkins test ~60 times (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Fix ipc load/dump for io.BytesIO input/output (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Add dump for semaphores (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add handling of msgqueue (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add dump method for shmem pages (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add payload handler for shmem pages (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Add payload handler for semaphore images (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add step-by-step execution (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Print out and strace file names (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Print test output on screen when possible (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: catch KeyError instead of ValueError for sets (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: fix a race between restoring namespaces and file mappings (v2) (Pavel
Emelyanov <xemul@parallels.com>)
 - mount: pick out a function to set ROOT_FD_OFF (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Fix casts for fixed and sfixed types (Pavel Emelyanov
<xemul@parallels.com>)
 - seize: get_freezer_state -- Relax stack (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: set a type argument for mknod (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't worry if uns isn't in run_flavs (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: stop doing anything if populate_mnt_ns() failed (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't worry if a binfmt_misc image is empty (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Fix CRIT test to skip non-criu images and provide cumulative output
(Pavel Emelyanov <xemul@parallels.com>)
 - mount: don't add dot to a path (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Pretty print vma flags and status (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: umount a temporary mount with MTN_DETACH (Pavel Emelyanov
<xemul@parallels.com>)
 - pagemap-cache: add const-qualifier to pmc's vma (Pavel Emelyanov
<xemul@parallels.com>)
 - page-xfer: fix wrong hole address offset (Pavel Emelyanov
<xemul@parallels.com>)
 - test: Add inotify02 (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Fix zdtm_test._env data type (Pavel Emelyanov <xemul@parallels.com>)
 - sysctl: don't skip erros (Pavel Emelyanov <xemul@parallels.com>)
 - sysctl: really skip missing entries in __nonuserns_sysctl_op() (Pavel
Emelyanov <xemul@parallels.com>)
 - criu: x86_32: change stack align to 16 bit on parasite head (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: add the mnt_id feature if a test uses more than one mntns (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm.py: skip the uns flavor if userns isn't suppported (Pavel Emelyanov
<xemul@parallels.com>)
 - lsm: add a --lsm-profile flag (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Encode back pretty IP addresses (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Show devices nicely (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: Add test for crit de/encode correctness (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Run tests in best flavor (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Count skipped tests (Pavel Emelyanov <xemul@parallels.com>)
 - mount: don't rewrite root for external mounts (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41932)
 - unix: Add support for restoring receive queue for unix DGRAM sockets (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm: add mntns_rw_ro_rw to the test list (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: fix restoring a bind-mount when its root is overmounted (Pavel
Emelyanov <xemul@parallels.com>)
 - mount: refactor do_bind_mount() (Pavel Emelyanov <xemul@parallels.com>)
 - mount: pick out a function to bind mount a point in a tmp place (Pavel
Emelyanov <xemul@parallels.com>)
 - mnt: Carry run-time device ID in mount_info (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41610)
 - zdtm.py: The groups_test class for running groups (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Generator of groups of tests (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Prepare zdtm_test and flavors for mass test start (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Remove unneeded re-exec (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Factor out ps showing code (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Introduce explicit prepare_namespaces() routine (Pavel Emelyanov
<xemul@parallels.com>)
 - fs: Add binfmt_misc support (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Add socket_close_data01 test (Pavel Emelyanov <xemul@parallels.com>)
 - fixed repository url
 - Prepare for builds from forked repository

* Wed Dec 23 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-6
- backport 0004-criu-tty-pick-only-master-as-a-control-terminal.patch, #PSBM-42590

* Thu Dec 17 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-5
- backport 0003-seize-don-t-wory-if-a-cgroup-contains-some-extra-tas.patch, #PSBM-42145

* Wed Dec 9 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-4
- backport 0002-mnt-Carry-run-time-device-ID-in-mount_info.patch, #PSBM-41610

* Mon Dec 7 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-3
- backport 0001-mount-dont-rewrite-root-for-external-mounts.patch, #PSBM-41932

* Mon Dec 7 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-2
- Update to 1.8

* Mon Nov 30 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-1.rc1
- criu segmentation fault, coredump created, #PSBM-41394

* Mon Nov 16 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-7
- backport 0009-tty-open-all-terminals-with-O_NOCTTY.patch

* Mon Nov 16 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-6
- backport 0008-tty-Restore-controlling-terminal-once-per-session.patch

* Thu Nov 12 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-5
- remove 0008-rst-Re-use-opened-fd-when-restoring-private-mappings.patch

* Wed Nov 11 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-4
- backport 0007-page-server-Fine-grained-corking-control-v3.patch
- backport 0008-rst-Re-use-opened-fd-when-restoring-private-mappings.patch

* Tue Nov 3 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-3
- backport 0006-fsnotify-Add-ability-to-force-resolve-paths-for-watc.patch

* Thu Oct 29 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-2
- backport 0001-ptrace-don-t-stop-a-process-if-it-was-not-in-the-sto.patch
- backport 0002-bfd-add-breadchr.patch
- backport 0003-proc-read-all-data-from-proc-pid-task-tid-children-v.patch
- backport 0004-proc-parse_children-appens-new-processes-to-a-specif.patch
- backport 0005-seize-don-t-catch-all-processes-from-a-freezer-cgrou.patch

* Wed Oct 28 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2
- Update to 1.7.2

* Mon Oct 26 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.1-2
- backport 0001-ipc-save-local-user-and-group-id-s-for-ipc-objects.patch
- backport 0002-sk-unix-Fix-typo-in-name-length-estimation.patch

* Fri Oct 23 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.1
- Update to 1.7.1

* Tue Oct 20 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7-2
- Add criu-d150d6f2-freezer_dont_catch_kernel_threads.patch

* Mon Sep 7 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7
- Update to 1.7

* Wed Aug 12 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.6.1
- Update to 1.6.1

* Tue Jul 7 2015 Nikita Spiridonov <nspiridonov@odin.com> - 1.6-2
- Rebuild with new protobuf-c package

* Thu Jun 18 2015 Nikita Spiridonov <nspiridonov@odin.com> - 1.6
- Update to 1.6

* Sun Apr 19 2015 Nikita Spiridonov <nspiridonov@odin.com> - 1.5.1-2
- Create python-criu and crit subpackages

* Tue Mar 31 2015 Andrew Vagin <avagin@openvz.org> - 1.5.1
- Update to 1.5.1

* Sat Dec 06 2014 Adrian Reber <adrian@lisas.de> - 1.4-1
- Update to 1.4

* Tue Sep 23 2014 Adrian Reber <adrian@lisas.de> - 1.3.1-1
- Update to 1.3.1 (#1142896)

* Tue Sep 02 2014 Adrian Reber <adrian@lisas.de> - 1.3-1
- Update to 1.3
- Dropped all upstreamed patches
- included pkgconfig file in -devel

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Aug 07 2014 Andrew Vagin <avagin@openvz.org> - 1.2-4
- Include inttypes.h for PRI helpers

* Thu Aug 07 2014 Andrew Vagin <avagin@openvz.org> - 1.2-3
- Rebuilt for https://bugzilla.redhat.com/show_bug.cgi?id=1126751

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Feb 28 2014 Adrian Reber <adrian@lisas.de> - 1.2-1
- Update to 1.2
- Dropped all upstreamed patches

* Tue Feb 04 2014 Adrian Reber <adrian@lisas.de> - 1.1-4
- Create -devel subpackage

* Wed Dec 11 2013 Andrew Vagin <avagin@openvz.org> - 1.0-3
- Fix the epoch of crtools

* Tue Dec 10 2013 Andrew Vagin <avagin@openvz.org> - 1.0-2
- Rename crtools to criu #1034677

* Wed Nov 27 2013 Andrew Vagin <avagin@openvz.org> - 1.0-1
- Update to 1.0

* Thu Oct 24 2013 Andrew Vagin <avagin@openvz.org> - 0.8-1
- Update to 0.8

* Tue Sep 10 2013 Andrew Vagin <avagin@openvz.org> - 0.7-1
- Update to 0.7

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 24 2013 Andrew Vagin <avagin@openvz.org> - 0.6-3
- Delete all kind of -fstack-protector gcc options

* Wed Jul 24 2013 Andrew Vagin <avagin@openvz.org> - 0.6-3
- Added arm macro to ExclusiveArch

* Wed Jul 03 2013 Andrew Vagin <avagin@openvz.org> - 0.6-2
- fix building on ARM
- fix null pointer dereference

* Tue Jul 02 2013 Adrian Reber <adrian@lisas.de> - 0.6-1
- updated to 0.6
- upstream moved binaries to sbin
- using upstream's make install

* Tue May 14 2013 Adrian Reber <adrian@lisas.de> - 0.5-1
- updated to 0.5

* Fri Feb 22 2013 Adrian Reber <adrian@lisas.de> - 0.4-1
- updated to 0.4

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Jan 22 2013 Adrian Reber <adrian@lisas.de> - 0.3-3
- added ExclusiveArch blocker bug

* Fri Jan 18 2013 Adrian Reber <adrian@lisas.de> - 0.3-2
- improved Summary and Description

* Mon Jan 14 2013 Adrian Reber <adrian@lisas.de> - 0.3-1
- updated to 0.3
- fix building Documentation/

* Tue Aug 21 2012 Adrian Reber <adrian@lisas.de> - 0.2-2
- remove macros like %%{__mkdir_p} and %%{__install}
- add comment why it is only x86_64

* Tue Aug 21 2012 Adrian Reber <adrian@lisas.de> - 0.2-1
- initial release
